(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    361433,       8198]
NotebookOptionsPosition[    331559,       7441]
NotebookOutlinePosition[    348599,       7803]
CellTagsIndexPosition[    348102,       7784]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Algorithms", "BookChapterTitle",
 CounterAssignments->{{"ChapterNumber", 3}}],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
 "In this chapter we supplement the discussion of algorithms presented in the \
text with their implementation in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". In Section 3.1, we discuss the process of turning step-by-step \
instructions describing a procedure and pseudocode for a procedure into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code. In the second section, we make use of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s graphing capabilities to visualize functions related by \
the big-O notation. And in Section 3.3, we explore average-case complexity of \
algorithms by considering the performance of a function on input."
}], "Text"],

Cell[TextData[{
 "In this chapter, please keep in mind the difference between an algorithm \
and its implementation (referred to as a function in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " parlance). An algorithm refers to an approach to solving a particular \
problem, while a function is the implementation of the algorithm within ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". In this manual, we will also distinguish between complexity and \
performance. Complexity is a measure of an algorithm and is generally \
measured by counting basic operations such as comparisons, while performance \
takes into account additional factors related to the specifics of an \
implementation and can be measured by recording the time it takes for the \
function to complete. Some of the factors affecting performance may include: \
choice of data structures and how the system implements those structures, the \
kinds of loops employed and how those are implemented by the computer \
language, and various improvements to efficiency handled by the system (for \
example, many computer languages, when evaluating a Boolean expression such \
as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "\[And]", "q"}], TraditionalForm]]],
 ", will not bother checking ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]]],
 " if ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 " is found to be false thereby decreasing the number of operations that need \
to be performed)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.1 Algorithms", "Section",
 CellTags->"Section1"],

Cell[TextData[{
 "It is impossible to overemphasize the importance and utility of writing \
either pseudocode or step-by-step instructions for an algorithm before you \
write the actual code for the function. Doing so helps you organize your \
ideas about how to solve the problem without the rigid constraints of the \
particular programming language. The textbook serves as an excellent model \
for you as you learn how to turn mathematical concepts and solutions to \
problems into algorithms. Those algorithms can then be turned into functions \
in any programming language you choose. This manual will help you turn your \
pseudocode or step-by-step instructions for algorithms into functions written \
in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[TextData[{
 "Section 3.1 of the textbook describes several algorithms, with an emphasis \
on how you can describe these algorithms using both English descriptions and \
pseudocode. Here, we will see how to implement several of these algorithms in \
",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". In this chapter, it will be especially important for you to have the text \
alongside you, as we will not reproduce the descriptions of the algorithms \
from the text."
}], "Text"],

Cell[CellGroupData[{

Cell["Find Maximum", "Subsection",
 CellTags->"Section1a"],

Cell["\<\
The first algorithm we will implement is the algorithm for finding the \
maximum in an unsorted sequence. This is described in Section 3.1 in the \
solution to Example 1 as step-by-step instructions and as pseudocode in \
Algorithm 1. We will build the function according to the step-by-step \
instructions. In order to make the connection between the instructions and \
the code as clear as possible, we\[CloseCurlyQuote]ll begin with a function \
with no statements and successively revise it to show the addition of each \
step. Be warned that the incomplete versions of the function may produce \
errors, if you execute the definitions.\
\>", "Text"],

Cell[TextData[{
 "We begin with the basic elements of the function definition without code. \
Specifically, we include the name of the function, a pattern to impose the \
type of the argument, and, since we will have local variables, the ",
 StyleBox[ButtonBox["Module",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Module"], "FunctionLink"],
 " function and its basic structural elements."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"findMax", "[", 
   RowBox[{"L", ":", 
    RowBox[{"{", "__Integer", "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ","}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "]"}]}]], "myCode",
 AutoStyleOptions->{"HighlightMissingArguments"->False}],

Cell[TextData[{
 "Note that the pattern specifying the type of the argument indicates that \
the function will accept a list (indicated by the braces) which consists of a \
sequence (indicated by the ",
 StyleBox[ButtonBox["BlankSequence",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/BlankSequence"], "FunctionLink"],
 " (",
 StyleBox["_\[ThinSpace]_", "Input"],
 ")) of at least one integer. The ",
 StyleBox["L:", "Input"],
 " means that the argument will be referred to as ",
 StyleBox["L", "Input"],
 "."
}], "Text"],

Cell["\<\
Step 1 in the step-by-step instructions is to \[OpenCurlyDoubleQuote]set the \
temporary maximum equal to the first integer\[CloseCurlyDoubleQuote] in the \
list. We declare a local variable to store the temporary maximum and add a \
statement in the body of the function to assign the first integer in the list \
to this value.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"findMax", "[", 
   RowBox[{"L", ":", 
    RowBox[{"{", "__Integer", "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "tempMax", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tempMax", "=", 
      RowBox[{"L", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "]"}]}]], "myCode"],

Cell[TextData[{
 "Step 2, according to Example 1 of the text, is to compare the next integer \
to the temporary maximum and update the temporary maximum if necessary. This \
requires an ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statement to make the comparison."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"findMax", "[", 
   RowBox[{"L", ":", 
    RowBox[{"{", "__Integer", "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "tempMax", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tempMax", "=", 
      RowBox[{"L", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"tempMax", "<", 
        RowBox[{"L", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", 
       RowBox[{"tempMax", "=", 
        RowBox[{"L", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}], ";"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}]], "myCode"],

Cell[TextData[{
 "(We are intentionally following the step-by-step instructions to the \
letter, so in step 2, \[OpenCurlyDoubleQuote]the next integer\
\[CloseCurlyDoubleQuote] is ",
 StyleBox["L[2]", "Input"],
 ".)"
}], "Text"],

Cell[TextData[{
 "Step 3 tells us to repeat step 2 for all of the integers in the list. We \
need to revise our code as follows. The fact that we are supposed to repeat \
step 2 means that we\[CloseCurlyQuote]ll need a loop. And since this loop is \
supposed to consider all of the elements of the list beyond the first means \
that we use a ",
 StyleBox[ButtonBox["For",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/For"], "FunctionLink"],
 " loop over the indices of the list starting at 2. We put the code we wrote \
for step 2 inside this loop, since that\[CloseCurlyQuote]s the instruction \
being repeated, and replace the specific index \[OpenCurlyDoubleQuote]2\
\[CloseCurlyDoubleQuote] with the loop variable. Finally, the loop variable \
needs to be added to the list of ",
 StyleBox[ButtonBox["Module",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Module"], "FunctionLink"],
 " variables."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"findMax", "[", 
   RowBox[{"L", ":", 
    RowBox[{"{", "__Integer", "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tempMax", ",", "i"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tempMax", "=", 
      RowBox[{"L", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "2"}], ",", 
       RowBox[{"i", "\[LessEqual]", 
        RowBox[{"Length", "[", "L", "]"}]}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"tempMax", "<", 
          RowBox[{"L", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"tempMax", "=", 
          RowBox[{"L", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}]}], "\[IndentingNewLine]",
       "]"}], ";"}]}], "\[IndentingNewLine]", "]"}]}]], "myCode"],

Cell["\<\
Finally, step 4 tells us that once the loop is completed, the value of the \
temporary maximum is the maximum, so we return that value.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"findMax", "[", 
   RowBox[{"L", ":", 
    RowBox[{"{", "__Integer", "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tempMax", ",", "i"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tempMax", "=", 
      RowBox[{"L", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "2"}], ",", 
       RowBox[{"i", "\[LessEqual]", 
        RowBox[{"Length", "[", "L", "]"}]}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"tempMax", "<", 
          RowBox[{"L", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"tempMax", "=", 
          RowBox[{"L", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}]}], "\[IndentingNewLine]",
       "]"}], ";", "\[IndentingNewLine]", "tempMax"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"findMax", "[", 
  RowBox[{"{", 
   RowBox[{"3", ",", "18", ",", 
    RowBox[{"-", "5"}], ",", "72", ",", "6", ",", "0"}], "}"}], 
  "]"}]], "Input"],

Cell[BoxData["72"], "Output"]
}, Open  ]],

Cell["\<\
Admittedly, this example may be a bit too simple to warrant such an elaborate \
process. But it illustrates an essential point: a well-written set of \
step-by-step instructions describing a procedure can be easily turned into \
working and correct code. Moreover, for non-trivial algorithms, the two-step \
process of writing instructions for the function and then implementing the \
function based on those instructions typically results in the production of a \
correct implementation more quickly than attempting the implementation \
without writing instructions.\
\>", "Text"],

Cell["\<\
Take a moment to compare the function above with the pseudocode given in \
Algorithm 1 in the textbook. You will notice that, in this example, they are \
extremely similar. This is one of the benefits of pseudocode in comparison to \
step-by-step instructions. However, step-by-step instructions are often \
easier to write as a first step towards a working function. Step-by-step \
instructions are also typically easier to understand, especially for novice \
programmers, as they can more easily accommodate explanation and other \
information that is out of place in pseudocode.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Binary Search", "Subsection",
 CellTags->"Section1b"],

Cell["\<\
The second example will be the binary search algorithm, presented as \
Algorithm 3 in Section 3.1. The previous example showed how you can use \
step-by-step instructions to build up the function. Starting from \
pseudo-code, writing the final implementation involves translating statements \
in the pseudocode into legal statements in the programming language and \
filling in missing details.\
\>", "Text"],

Cell[TextData[{
 "As before, we will go through several iterations as we translate the \
pseudocode in the text to actual ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code. Initially, we need to: make sure that the input is specified in a \
way appropriate for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "; declare the local variables that are indicated in the pseudocode; and \
make basic syntax adjustments, specifically the while loops, if statements, \
and mathematical expressions such as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[LeftFloor]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"i", "+", "j"}], ")"}], "/", "2"}], "\[RightFloor]"}], 
   TraditionalForm]]],
 " must be translated into their ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " counterparts."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"binarySearch", "[", 
   RowBox[{"x_Integer", ",", 
    RowBox[{"A", ":", 
     RowBox[{"{", "__Integer", "}"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "m", ",", "location"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"j", "=", "n"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"i", "<", "j"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"m", "=", 
         RowBox[{"Floor", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"i", "+", "j"}], ")"}], "/", "2"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"x", ">", 
           RowBox[{"A", "[", 
            RowBox[{"[", "m", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"i", "=", 
           RowBox[{"m", "+", "1"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"j", "=", "m"}]}], "\[IndentingNewLine]", "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"x", "\[Equal]", 
        RowBox[{"A", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"location", "=", "i"}], ",", "\[IndentingNewLine]", 
       RowBox[{"location", "=", "0"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", "location"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"],

Cell["\<\
It is too much to expect this first version to properly execute.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"binarySearch", "[", 
  RowBox[{"19", ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "5", ",", "6", ",", "7", ",", "8", ",", 
     "10", ",", "12", ",", "13", ",", "15", ",", "16", ",", "18", ",", "19", 
     ",", "20", ",", "22"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The problem is a simple one to correct. The pseudocode used ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " as the last index of the sequence of integers, so we need to make that \
assignment in our code."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"binarySearch", "[", 
   RowBox[{"x_Integer", ",", 
    RowBox[{"A", ":", 
     RowBox[{"{", "__Integer", "}"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", ",", "i", ",", "j", ",", "m", ",", "location"}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", "A", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"i", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"j", "=", "n"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"i", "<", "j"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"m", "=", 
         RowBox[{"Floor", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"i", "+", "j"}], ")"}], "/", "2"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"x", ">", 
           RowBox[{"A", "[", 
            RowBox[{"[", "m", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"i", "=", 
           RowBox[{"m", "+", "1"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"j", "=", "m"}]}], "\[IndentingNewLine]", "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"x", "\[Equal]", 
        RowBox[{"A", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"location", "=", "i"}], ",", "\[IndentingNewLine]", 
       RowBox[{"location", "=", "0"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", "location"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell["Now we try running it again.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"binarySearch", "[", 
  RowBox[{"19", ",", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "5", ",", "6", ",", "7", ",", "8", ",", 
     "10", ",", "12", ",", "13", ",", "15", ",", "16", ",", "18", ",", "19", 
     ",", "20", ",", "22"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData["14"], "Output"]
}, Open  ]],

Cell[TextData[{
 "Observe that the only commands that we added were the declaration of local \
variables, and the assignment of ",
 StyleBox["n", "Input"],
 ". We also added additional line breaks to be consistent with the style of \
code used in this manual. Otherwise, the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code and pseudocode match very closely. It is, of course, not always quite \
this straightforward, but well-written pseudocode should contain all the \
essential elements. Like with proofs, as you become more familiar with \
pseudocode you will find yourself more comfortable with leaving some details \
out."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Bubble Sort", "Subsection",
 CellTags->"Section1c"],

Cell["\<\
As a final example, we will implement the bubble sort, presented in the text \
as Algorithm 4 of Section 3.1.\
\>", "Text"],

Cell["\<\
For our first attempt at implementing Algorithm 4, we need to: specify the \
input, declare the local variables (which can, in part, be gleaned from the \
pseudocode), and correct the syntax for the for loops and if statements.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bubbleSort", "[", "A_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "j"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"n", "-", "1"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"j", "=", "1"}], ",", 
        RowBox[{"j", "\[LessEqual]", 
         RowBox[{"n", "-", "i"}]}], ",", 
        RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"[", "j", "]"}], "]"}], ">", 
           RowBox[{"A", "[", 
            RowBox[{"[", 
             RowBox[{"j", "+", "1"}], "]"}], "]"}]}], ","}], 
         "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{"then", " ", "interchange", " ", 
           RowBox[{"A", "[", 
            RowBox[{"[", "j", "]"}], "]"}], " ", "and", " ", 
           RowBox[{"A", "[", 
            RowBox[{"[", 
             RowBox[{"j", "+", "1"}], "]"}], "]"}]}], "*)"}], 
         "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}]], "myCode",\

 AutoStyleOptions->{"HighlightMissingArguments"->False}],

Cell[TextData[{
 "The implementation above gets us close to a correct implementation of the \
bubble sort algorithm, but there are some problems. The simplest to fix is \
that ",
 StyleBox["n", "Input"],
 " is not defined. You can correct this in one of two ways. Either declare ",
 StyleBox["n", "Input"],
 " as a local variable and set it equal to the number of elements of ",
 StyleBox["A", "Input"],
 ", or replace the two occurrences of ",
 StyleBox["n", "Input"],
 " with ",
 StyleBox["Length[A]", "Input"],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bubbleSort", "[", "A_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", 
      RowBox[{"n", "=", 
       RowBox[{"Length", "[", "A", "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", 
       RowBox[{"n", "-", "1"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"j", "=", "1"}], ",", 
        RowBox[{"j", "\[LessEqual]", 
         RowBox[{"n", "-", "i"}]}], ",", 
        RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"A", "[", 
            RowBox[{"[", "j", "]"}], "]"}], ">", 
           RowBox[{"A", "[", 
            RowBox[{"[", 
             RowBox[{"j", "+", "1"}], "]"}], "]"}]}], ","}], 
         "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{"then", " ", "interchange", " ", 
           RowBox[{"A", "[", 
            RowBox[{"[", "j", "]"}], "]"}], " ", "and", " ", 
           RowBox[{"A", "[", 
            RowBox[{"[", 
             RowBox[{"j", "+", "1"}], "]"}], "]"}]}], "*)"}], 
         "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}]], "myCode",\

 AutoStyleOptions->{"HighlightMissingArguments"->False}],

Cell[TextData[{
 "The next problem is the instruction in the pseudocode to interchange ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "j"], TraditionalForm]]],
 " with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"j", "+", "1"}]], TraditionalForm]]],
 ". ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " contains no interchange function. So we'll either have to make an \
interchange function that can be used within the ",
 StyleBox["bubbleSort", "Input"],
 " function or flesh out the code to interchange the two list elements within \
",
 StyleBox["bubbleSort", "Input"],
 " itself. We take the first approach here so as to preserve as close a \
connection as possible between our implementation and the pseudocode."
}], "Text"],

Cell[TextData[{
 "Before creating an ",
 StyleBox["interchange", "Input"],
 " function, however, there is another issue to take into consideration. \
Namely, in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", arguments to a function cannot be modified. Instead, we need to copy the \
parameter to a local variable, both in ",
 StyleBox["bubbleSort", "Input"],
 " and in the ",
 StyleBox["interchange", "Input"],
 " function we are about to write."
}], "Text"],

Cell[TextData[{
 "Our ",
 StyleBox["interchange", "Input"],
 " function will take two arguments: the list of numbers and the index of the \
smaller of the two positions to be swapped. It will proceed as follows: "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Set a temporary variable equal to the first value to be swapped.\
\>", "Item1Numbered"],

Cell["\<\
Set the value of the first position equal to the second value.\
\>", "Item1Numbered"],

Cell["\<\
Set the value of the second position equal to the value stored in the \
temporary variable.\
\>", "Item1Numbered"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"interchange", "[", 
   RowBox[{"L_List", ",", "i_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"M", "=", "L"}], ",", "temp"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"temp", "=", 
      RowBox[{"M", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"M", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "=", 
      RowBox[{"M", "[", 
       RowBox[{"[", 
        RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"M", "[", 
       RowBox[{"[", 
        RowBox[{"i", "+", "1"}], "]"}], "]"}], "=", "temp"}], ";", 
     "\[IndentingNewLine]", "M"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",\

 InitializationCell->True],

Cell[TextData[{
 "Now we update our implementation by: copying the list to a local name and \
replacing all the occurrences of the parameter with the local variable; \
applying the ",
 StyleBox["interchange", "Input"],
 " function; and ending with the local copy of the list, so that it is the \
output of the function."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bubbleSort", "[", "A_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", 
      RowBox[{"n", "=", 
       RowBox[{"Length", "[", "A", "]"}]}], ",", 
      RowBox[{"B", "=", "A"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", 
        RowBox[{"n", "-", "1"}]}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", 
          RowBox[{"n", "-", "i"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"B", "[", 
             RowBox[{"[", "j", "]"}], "]"}], ">", 
            RowBox[{"B", "[", 
             RowBox[{"[", 
              RowBox[{"j", "+", "1"}], "]"}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"B", "=", 
            RowBox[{"interchange", "[", 
             RowBox[{"B", ",", "j"}], "]"}]}]}], "\[IndentingNewLine]", 
          "]"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
      "]"}], ";", "\[IndentingNewLine]", "B"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bubbleSort", "[", 
  RowBox[{"{", 
   RowBox[{"3", ",", "18", ",", 
    RowBox[{"-", "5"}], ",", "72", ",", "6", ",", "0"}], "}"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "5"}], ",", "0", ",", "3", ",", "6", ",", "18", ",", "72"}], 
  "}"}]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2 The Growth of Functions", "Section",
 CellTags->"Section2"],

Cell[TextData[{
 "In this section we will use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to computationally explore the growth of functions. In particular, we will \
graph functions in order to visually convince ourselves that the big-O \
relationship is satisfied. We will also see how to use graphs to determine \
possible witnesses for the constants ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 " in the definition of big-O notation. Since, as the textbook mentions, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "x", ")"}], TraditionalForm]]],
 " is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    RowBox[{"g", "(", "x", ")"}], ")"}], TraditionalForm]]],
 " if and only if ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "x", ")"}], TraditionalForm]]],
 " is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalOmega]", "(", 
    RowBox[{"f", "(", "x", ")"}], ")"}], TraditionalForm]]],
 ", the techniques we explore in this section apply also to big-Omega and \
big-Theta notation."
}], "Text"],

Cell[TextData[{
 "We begin by considering the function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    RowBox[{
     RowBox[{"5", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{"4", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"3", "x"}], "+", "9"}]}], TraditionalForm]]],
 ". Theorem 1 from Section 3.2 tells us that this is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SuperscriptBox["x", "3"], ")"}], TraditionalForm]]],
 ", but we will use this function as an example of how you can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find values for ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 " such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"|", 
    RowBox[{"f", "(", "x", ")"}], "|", 
    RowBox[{"\[LessEqual]", "C"}], "|", 
    RowBox[{"g", "(", "x", ")"}], "|"}], TraditionalForm]]],
 " for all ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "\[GreaterEqual]", "k"}], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "The ",
 StyleBox["Plot", "Input"],
 " Function"
}], "Subsection",
 CellTags->"Section2a"],

Cell[TextData[{
 "First we\[CloseCurlyQuote]ll look at options to the ",
 StyleBox[ButtonBox["Plot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Plot"], "FunctionLink"],
 " function that will be useful in this context. Let\[CloseCurlyQuote]s start \
by giving names to the formulas."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f1", "=", 
  RowBox[{
   RowBox[{"5", "*", 
    RowBox[{"x", "^", "3"}]}], "+", 
   RowBox[{"4", "*", 
    RowBox[{"x", "^", "2"}]}], "+", 
   RowBox[{"3", "*", "x"}], "+", "9"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"9", "+", 
  RowBox[{"3", " ", "x"}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"5", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g1", "=", 
  RowBox[{"x", "^", "3"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 SuperscriptBox["x", "3"]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Graphing ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "x", ")"}], TraditionalForm]]],
 " can be done as simply as calling ",
 StyleBox[ButtonBox["Plot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Plot"], "FunctionLink"],
 " with the function as the first argument and a specification of the domain \
as the second.",
 " ",
 "The domain specification is given as a list consisting of the name of the \
independent variable used in the function, the minimum value, and the maximum \
value. "
}], "Text"],

Cell[TextData[{
 "For example, to display the graph of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "x", ")"}], TraditionalForm]]],
 " with ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " ranging from 0 to 10, you enter the following."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"f1", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "10"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlnk41PsfxZlBSbqWmiLLmO/Yxl6U/fNGRWiULF0pkZBK6VLZosgSynYZ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 10}, {0., 5438.999676938782}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " automatically selects the vertical range of the graph. You can control \
this with the ",
 StyleBox[ButtonBox["PlotRange",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotRange"], "FunctionLink"],
 " option. The first two common values for ",
 StyleBox[ButtonBox["PlotRange",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotRange"], "FunctionLink"],
 " are ",
 StyleBox["Automatic", "Input"],
 " and ",
 StyleBox["All", "Input"],
 ". The ",
 StyleBox["Automatic", "Input"],
 " value has the same effect as omitting the option. The difference between \
",
 StyleBox["Automatic", "Input"],
 " and ",
 StyleBox["All", "Input"],
 " is that, in certain circumstances, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " may decide that parts of the function being graphed are outliers and may \
choose to omit them when using the ",
 StyleBox["Automatic", "Input"],
 " plot range. The ",
 StyleBox["All", "Input"],
 " value forces ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to display the entire function. This is illustrated below, where we have \
graphed ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "10"], TraditionalForm]]],
 " with both options. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"x", "^", "10"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "5"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "Automatic"}]}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"x", "^", "10"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "5"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVV3c4128XtvemQcgK2bOs7+c8X9lJkZ29UiIqUSmFkOzsZEVRyQhZWRFZ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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    Method->{},
    PlotRange->{{0., 4.999999897959183}, {0., 3.526348860245497*^6}},
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]},
    ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVV3c8198XtvemoZAVMrPK+nzOfdskIjt7pUQopVKEkOysZEeRZCRZWZGy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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    Method->{},
    PlotRange->{All, All},
    PlotRangeClipping->True,
    PlotRangePadding->{Automatic, Automatic},
    ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Another common use of ",
 StyleBox[ButtonBox["PlotRange",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotRange"], "FunctionLink"],
 " is to explicitly specify the maximum and minimum ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 " values. If you provide a single positive number as the value for ",
 StyleBox[ButtonBox["PlotRange",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotRange"], "FunctionLink"],
 ", ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will display the graph with that value as the maximum for the vertical \
axis and its negative as the minimum. The following graphs ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "x", ")"}], TraditionalForm]]],
 " with ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " from 0 to 10 and the vertical axis ranging from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "5000"}], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox["5000", TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"f1", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "5000"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlnk4FIgfxseMI6ldR81GjjEzGOMucvf9OopclRwtSiRKpbRdjqLIkSPX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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 10}, {-5000, 5000}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",ImageCache->GraphicsData[\
"CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[TextData[{
 "If you wish to specify different values for the maximum and minimum for the \
vertical axis, you can do so with a list consisting of the two values. The \
following shows ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "x", ")"}], TraditionalForm]]],
 " on the domain ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{"0", ",", "10"}], "]"}], TraditionalForm]]],
 " with the vertical axis ranging from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1000"}], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox["5000", TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"f1", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1000"}], ",", "5000"}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlnk4FIgfxseMI6ldR81GjjEzGOMucvf9OopclRwtSiRKpbRdjqLIkSPX
MgjLj0LGFZUjlSNkitjkKnJG5ByVqF/7Ps/7fJ73j8//r6z7GdtjRAKBwPrV
/5hx1Z1fwyNqJ00uahOBQMXGLoqVI+UEaPUOkmp4qfjzeV0IheIHFaOGM0GC
VMx4GiPDR4mEMDugMsSoeMrwwukvMqkQ2nvZmCtPxa7vx5PmZAqgJaKjMX0f
FS82S6vPlhXCwyMJ8yQHKkok/ts2Y1IEf/YRJy85U9GdiaRPXiVgxSdeFOJJ
xctFQlULb8thJEC/VOUKFQX6hxVmZKqg+bu7+FgRFXuePr4w/bEKNtwej/nj
PhUL77AaPpVVgxWjLsOxioo252xcp0xqYb9jAonnORWTBauTJ7yewIn9c5tW
B6koeruFOP+2Hmqaoh8WkWmY/SLL95NMK+xUZZk23KLhEquSORjdCqXZmWtx
LBru9mob6fzWChZtJd/PZdNwmvTFvrrrBYgHLzmdv09DHUMbvchwDvzO/KP8
bA8NO0pWiQqz7TBpA7Sz8nQUBcHDG1U7YPim5o1EdTrqyyfphXt0QKyfYeBL
PTrGLhUs+r/uAMni6Mc39tJRM/7NMfd7r2GdqnqqkD8dg14oW2i4dkHhQcHN
MV10zC97KH/v7y5olbtCURqkYyfLmCTH6QJazkaR4Sk60r0O1m7R/ReKJsK0
0oly+IIUqkoQewMCR6ZSdm6XQ7Jhv2j7825wfbNA9U6Vw+KSyP5Tqn3w0ear
vaO/PE6JTkVbuPWBpSpB2SlCHhUuWuxkJPWB6mR+7cVkefzHQCh75Fsf7E9y
Clsrl8eE1mhPp6Z+cNQs5t81I48XR27Nm7m8A03DBHK3pwJmCbWFiOwago3X
mHu7fBi40zDAJfjwEJQ/YHSbBTNwwEdJa/bSECy8r+jvjWfgls6ocU7hEGgV
LvU5VDIwnmW1J0L4A8xlXeM+XGNgiNyr3372fwByodWyepIiesHr1OlzI7Bs
Fkp83cNEQs5ydX/UCKhFbiQ3zjCRxSs58CJ3BIYaailviUrY0uopXdA9Av6L
5JhDKkrIsFvNOaY3CpP9Vwc+hyjhx+MKRe95xoD3jZGygbYyeidcqeuIGwfz
67Vo/lAFidycwScF43A7s1Hbt0MF0xxbCCX145BGNSp/PKmCLyTFTGKWxsFB
TfZ/zyRVUelufvOegxOgu2p063KoKk7XdHXUy3yEcU8lrxonNfQZUxypKJ4E
4kv3EXa8Og4d7l33rHUS1Ivzffqy1fFAT4Tqy9FJsDK7vyxVro46bRN+YxJT
UDoevWuqUx1JZXnC5PApePAkpjd1swayAmV3XnL9BMcF8io8sjTwmZh4qq7w
DOTb0vgZTdtQM6albpfSDJxs22Pi2LMN7/BfHt2/ewaEFSaeZn3ahtHfutW8
A2fgCGe1KVB0OzoMJj1P+/jLr2hfOO62HacKhZe+P/0MYYzFUnFeTVwvG6ow
qDMHTURmrPMhLWwxiFe7umsOmMM/Re3PaWHYwUxtKds5sEqlxHqGayEx7pGZ
88k5ELVUzHldpoUrP6a93mbMQfHwnXetAjvw04B9fjtxHk6KckL3PtqBHJaC
4lPOPNCXw++SlXXwZoWmhmvvPOzgCbyiZKqD5h1Guj/G5sHx+RzFyUUHGwVc
9hj8nAeyvokQX4wO1l6MO/FIYwHClvoEE2d1kG33raA0eQEi3trE367SxVjh
Nmb2kUVQHBJ5x3HTxyptqUobn0XIGmZ2hgbp4+jhM7AasAhn1FbhUIY+6rPF
7BxTFuFsypOOM736+HGPy5WNrxZBWTm+S+qAAZqEzLT76S9BcX16I9vKEL9y
f79gS+aC9HmNMMqfgDQp958/aVyoYZ8cFgoAtDGtiGRrcMGsSOp3iQzAvISD
meusueA/MUTP+gBoq5bdXBfCheY5ewWFHYjs49sklOa5sFOmJZjRiOjeb/eE
xFmGkUq9qMoZI1yf/uG0b+8ytKU1JcQRjLHcyUdycHwZgodcrl8RM0ZSX7hf
Nc8XEBNQNIzRNcbcnurtvtpfgPFbiPiNMGMcf0PJf5/zBYJ9WGrvaSbo3TEd
V+X3FcLato7+dcoUfZtC3c8orIBzogyftLYZSo/u5l/evgKZLXtlqdZm2EYU
LAzEFSASDj/RPmqGchgzH/nnCtS7vM9IuWWGvdV/B+dGrcAEdYnNnDRDo9I7
mb2zKxAQkemZm2WOIuktfSaPvgP/Z5P0LRIWWHZ2w4Ete9agmOMvmbLbGjlp
Yn5shzVIpv/gOX/UGscbJbKMPdbA9l1DulewNUqIK346FfRrm7YJJ1ZbY+iz
XSHPKtcgjl3Ds6pmgw6iQfe9qT/gweYyfmmZvbhyf17s8fcfEPis5JRv+D7M
Djg5pe5IwPprhfU66bZ4PWt1/9I0D0rlNt0MITkioWsIa/1JeG92v8HiBheU
P+952Y7Jh44yCtmj6m44yk1xEHrMj6bm4ksfkjzQYsz7SoLvOlwm5+nZNR5H
m9E4JWnp9ZhGavcVPX0apxrcg1vYQvg1OiY8RM4XVUW6pUxcN+LXGWMbW/J5
XA9ct4HF3/DY2mYVS9lLaDbj9IVqL4yar0BsodEfe+o9eJyURXD3h0qb0oqr
WBnReJjCFcH1M1fZC87X0JPvwtCrV6JYbBTDd7Y6BI+eC6jckCaG5kn5NEvZ
MFTzUnpl5bYJOeb2RwLvRWC7qLLQBd3N2OHBe46QG4U1xdfTlUlk7Lip/+BU
ViwG8DD3cd6R0axzjadVKB7XD/ib+1T8gf8e2NKYNJiAY3dkk7ICt6BB+IMD
e8uSMIkhzltlL445zIbPIW3JGJfm2exGkcC1lXymwDALnZIOvdowIYHdgrVE
/o3p+NU071tW3VYc8djczBOVgSNjxpfrwyVxTrDa7yjhH8wx1Nj60k0Kd4uo
d0mcyEb2jQsiXirSaOvTMJrBycFw+6OWJK40KpH6cun6uag1kF0Q/lIGyxJt
bx56l4csxXT2S0sKbp3V25Rw6S4GPY1hWVZR0E/j87KNRQFab7XPe0GXxX2u
xLJ4pXto5NPsLBIpi3opf12N52FjlqQ7ncOVRRfvxOlycgnSG+4m2/z6Mc7X
WfNBt0oxTqWe2VlHxcVN6aEHU8vQc5H3dSuThhHecqq05+V4nebtHnuahoT/
EnEf/w+yIFvn
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 10}, {-1000, 5000}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",ImageCache->GraphicsData[\
"CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[TextData[{
 "Finally, you can use ",
 StyleBox[ButtonBox["PlotRange",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotRange"], "FunctionLink"],
 " to specify the displayed range in both directions using the syntax ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["x", "min"], ",", 
       SubscriptBox["x", "max"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["y", "min"], ",", 
       SubscriptBox["y", "max"]}], "}"}]}], "}"}], TraditionalForm]]],
 ". Note that specifying the range for the horizontal axis in this way is \
quite different from setting the domain of the function, which is done with \
the second argument to ",
 StyleBox[ButtonBox["Plot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Plot"], "FunctionLink"],
 ". We illustrate the difference with the following example."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"f1", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "3", ",", "7"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "5000"}], "}"}]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVj2s0lAkAhie2ZlwSEzPNfFmpyKZCsWsSvSZnVlJJoaSpldJENMmS1pTc
Ve4rl77RLpEpTRRJmaTLTBRaNNios8llTS5dJCprf7znOc85z5/X2DfYfZ8a
hULZOL3/KXj1QZNCocGg/TZBueAPZ/Uhu2g1Gih5fvU+Rf4wM+0LnDWThmJV
xNXqK/7oDeho1NakwdTCnxlxyx9+n2rSWfo0MJ+Lgqkt/tijE89eZUZDbavU
3WfWAXiuYS3d70bD7i7HiuFDB+CUbb/+yQUadu06HHgfAmQZTGgabdZA5cEG
1hg7AKNGitCeUQ1sa3zosW4wECb1hpHhaZq4FxWYZCgPQhOnj5rhoIVHNRtl
EcLDiP6xzm7BKy1IlT06snAhro7rvl+Voo1lWpZLbvx5BGXefTyG3WysqTjs
6t4aAtn6pnUBf8+GutJU4vX1KBy/LX3AS9RBvO2C8irXX9G4Nvttpvkc7BRJ
rFPSw2BtfPZ6Wf0cKO7Hq5t3h4PWEyGS2OnC56fcou6tEZj8ejPM5owutmcE
v3tRcxwlE1fLo1/rYr5qgy3VIxJO8gE7DkcPM953bJp8L8Je71KWWaIe+o0k
qwXck3BoXsrpfKmH+q7dHRGLokBqW5U+tKTD1HOQ7P0ShSrzUd+jCXSUWzl8
XzhyCnfZH/cnddMxfujxjW390djQHHW3Y8VcyN794TZTGYP0A4odqti5KAzN
eev4Tyz48nPOtsq5SMmR17a8jgNjTBI7aKoP8lCNQL0/HonU8O98I/Xx17El
aRStRES9fKrUa9SHUZv1m66FSbDJ7VLFmBjAOo4V7rfzNNoWW7ntPm4AoupE
j+TcGUyEzqaFNBggZPyK1E5+Fp0lBTNcFjLQ3H4paZCVgrWFdZu9QxiofrXY
PtkiFalBJqpndQxQJtzi7FtScZ7g1muzmHAJ/ahZnZiG5Sl9X04KmMjVO12Y
b5uOY294wqpaJloNVy7fPpkOFzWL1T/Q5yFC+ttxrcoM0Ia9t8zwnQdheb79
TWEmomSQnK+ah4H0a9wE7u84sU3qJdRgocC44blAMwu2T5U8jV9YiNne7RLf
n4UuA6cY2k0WfDPkWg6Kc6CacBiOVDaGErwyNcTZUDH6B9bw2ahw+3xRdDoH
nk1G9CNSNug3+GNJQbko9cpL0JligxNw8ZqNex7u1jUjyINAW+zLVZ83nYfn
h+SN1CICAYzc564g8aCRaxlcTMBZ2zMy2YnEypIxuvISgZ0DouRmZxI6fH57
0WUC/hbLRjy2kHgoX76XV0Zg5FFc2T5fEtZ5T8Jj7xC4otZgmRNDQo+rWaje
QuBowSye22MSovmyuIBWAsPOYU75T0moxoSCljYC9+InS4eekVBc7lhR0E6g
uHhrXXIniZMGJbe43QR2uLaOtAySGOr/uSlqgIAhrUhwREcMn/uTZQP/EnjB
v0co6GLUk9LMLSoCX4rXcb5nilHkzvQ2HiZwrS+tssFIjF13entqPxC4Pt5b
bW413Wflys3Gpv/LGhQxNmLYCjdJUj8R0F3kyO3miKFvWhm8Z4KAX/67sHSu
GKcoB90VkwRWLuRYv+WJMdJpaGP5ddrZJj7OG8TgVzxjZn8jMHrn9nDBZjGe
pMROTE0RUIPa8NRWMf4DB4YqPQ==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 10}, {0, 5000}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",ImageCache->\
GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[TextData[{
 "You can see above that the ",
 StyleBox[ButtonBox["PlotRange",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotRange"], "FunctionLink"],
 " option is specifying the extent of the graph. On the other hand, the \
second argument, ",
 StyleBox["{x,3,7}", "Input"],
 " is a restriction of the domain of the function."
}], "Text"],

Cell[TextData[{
 "To plot multiple functions in the same graph, use the ",
 StyleBox[ButtonBox["Plot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Plot"], "FunctionLink"],
 " function with a list of functions as the first argument."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f1", ",", "g1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "5"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVxXk41IsaAOBhaEGF37mVc8Q0e2NrfUrF96FFKi2yJJEpYykcrkkiddBM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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlndUD/wfxVuKluqLp0RLSgMhIvneD4kWQkNbaaiM6pFKEZUGmlrSpoVI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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 5}, {0., 748.9999573469395}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " automatically selects colors for the two functions. You can manually \
select the colors (or other visual effects) with the ",
 StyleBox[ButtonBox["PlotStyle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotStyle"], "FunctionLink"],
 " option. If you use the ",
 StyleBox[ButtonBox["PlotStyle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotStyle"], "FunctionLink"],
 " option with a list of named colors, then the first color will be assigned \
to the first function, the second color to the second function, and so on. \
You can choose from common choices such as ",
 StyleBox["Red", "Input"],
 ", ",
 StyleBox["Green", "Input"],
 ", ",
 StyleBox["Blue", "Input"],
 ", ",
 StyleBox["Black", "Input"],
 ", ",
 StyleBox["White", "Input"],
 ", ",
 StyleBox["Gray", "Input"],
 ", ",
 StyleBox["Cyan", "Input"],
 ", ",
 StyleBox["Magenta", "Input"],
 ", ",
 StyleBox["Yellow", "Input"],
 ", ",
 StyleBox["Brown", "Input"],
 ", ",
 StyleBox["Orange", "Input"],
 ", ",
 StyleBox["Pink", "Input"],
 ", and ",
 StyleBox["Purple", "Input"],
 ". You can get more information about colors from ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s ",
 ButtonBox["Colors guide",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/Colors"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f1", ",", "g1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Orange", ",", "Purple"}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0.5, 0], LineBox[CompressedData["
1:eJwVxXk41IsaAOBhaEGF37mVc8Q0e2NrfUrF96FFKi2yJJEpYykcrkkiddBM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     "]]}, 
   {RGBColor[0.5, 0, 0.5], LineBox[CompressedData["
1:eJwVlndUD/wfxVuKluqLp0RLSgMhIvneD4kWQkNbaaiM6pFKEZUGmlrSpoVI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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 5}, {0., 748.9999573469395}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",ImageCache->GraphicsData["CompressedBitmap", \
"\<\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\
\>"]]
}, Open  ]],

Cell[TextData[{
 "When displaying graphs of multiple functions, it can often be useful to \
include a legend with the graph indicating which function is which. In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", you can use the ",
 StyleBox[ButtonBox["PlotLegends",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotLegends"], "FunctionLink"],
 " option to do this. "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["PlotLegends",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotLegends"], "FunctionLink"],
 " is an option to ",
 StyleBox[ButtonBox["Plot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Plot"], "FunctionLink"],
 " (and other plotting functions such as ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ListPlot"], "FunctionLink"],
 "). We will describe three of the possible values. "
}], "Text"],

Cell[TextData[{
 "The simplest way to create a legend is by setting the ",
 StyleBox[ButtonBox["PlotLegends",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotLegends"], "FunctionLink"],
 " option to ",
 StyleBox[ButtonBox["Automatic",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Automatic"], "FunctionLink"],
 ". This will create a legend that identifies the colors used in the plot \
with the index of the function."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f1", ",", "g1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", "Automatic"}]}], "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {}, {
      Hue[0.67, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVxXk41IsaAOBhaEGF37mVc8Q0e2NrfUrF96FFKi2yJJEpYykcrkkiddBM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       "]]}, {
      Hue[0.9060679774997897, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVlndUD/wfxVuKluqLp0RLSgMhIvneD4kWQkNbaaiM6pFKEZUGmlrSpoVI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       "]]}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
    PlotRange -> {{0, 5}, {0., 748.9999573469395}}, PlotRangeClipping -> True,
     PlotRangePadding -> {
      Scaled[0.02], 
      Scaled[0.02]}],TemplateBox[{
     TagBox[
      FrameBox[
       StyleBox["1", StripOnInput -> False, FontSize -> Smaller]], 
      "Placeholder"], 
     TagBox[
      FrameBox[
       StyleBox["2", StripOnInput -> False, FontSize -> Smaller]], 
      "Placeholder"]}, "LineLegend", DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{
             TagBox[#, HoldForm], ",", 
             TagBox[#2, HoldForm]}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Setting the ",
 StyleBox[ButtonBox["PlotLegends",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotLegends"], "FunctionLink"],
 " option to \[OpenCurlyDoubleQuote]Expressions\[CloseCurlyDoubleQuote] is \
much more descriptive, showing the expression that is being graphed."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f1", ",", "g1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", "\"\<Expressions\>\""}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {}, {
      Hue[0.67, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVxXk41IsaAOBhaEGF37mVc8Q0e2NrfUrF96FFKi2yJJEpYykcrkkiddBM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       "]]}, {
      Hue[0.9060679774997897, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVlndUD/wfxVuKluqLp0RLSgMhIvneD4kWQkNbaaiM6pFKEZUGmlrSpoVI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       "]]}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
    PlotRange -> {{0, 5}, {0., 748.9999573469395}}, PlotRangeClipping -> True,
     PlotRangePadding -> {
      Scaled[0.02], 
      Scaled[0.02]}],TemplateBox[{
     TagBox[
      FormBox[
       TagBox[
        RowBox[{"9", "+", 
          RowBox[{"3", " ", "x"}], "+", 
          RowBox[{"4", " ", 
            SuperscriptBox["x", "2"]}], "+", 
          RowBox[{"5", " ", 
            SuperscriptBox["x", "3"]}]}], HoldForm], TraditionalForm], 
      TraditionalForm, Editable -> True], 
     TagBox[
      FormBox[
       TagBox[
        SuperscriptBox["x", "3"], HoldForm], TraditionalForm], 
      TraditionalForm, Editable -> True]}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output"]
}, Open  ]],

Cell["\<\
Finally, you can specify your own labels by assigning the option to a list \
containing the expressions to use to identify the functions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f1", ",", "g1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<f\>\"", ",", "\"\<g\>\""}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {}, {
      Hue[0.67, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVxXk41IsaAOBhaEGF37mVc8Q0e2NrfUrF96FFKi2yJJEpYykcrkkiddBM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       "]]}, {
      Hue[0.9060679774997897, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVlndUD/wfxVuKluqLp0RLSgMhIvneD4kWQkNbaaiM6pFKEZUGmlrSpoVI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       "]]}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
    PlotRange -> {{0, 5}, {0., 748.9999573469395}}, PlotRangeClipping -> True,
     PlotRangePadding -> {
      Scaled[0.02], 
      Scaled[0.02]}],
   TemplateBox[{"\"f\"", "\"g\""}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " provides other possible values for the ",
 StyleBox[ButtonBox["PlotLegends",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotLegends"], "FunctionLink"],
 " option to influence the placement of the legend. It also has more general \
functions, particularly ",
 StyleBox[ButtonBox["LineLegend",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/LineLegend"], "FunctionLink"],
 ", that gives you the ability to completely customize the content and format \
of the legend."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Finding Values for ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]]
}], "Subsection",
 CellTags->"Section2b"],

Cell[TextData[{
 "Now we can start exploring different values of ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]]],
 " for which the equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "\[LessEqual]", 
    RowBox[{"C", "\[CenterDot]", 
     RowBox[{"g", "(", "x", ")"}]}]}], TraditionalForm]]],
 " is satisfied. To do this, we just have to multiply ",
 StyleBox["g1", "Input"],
 " by different values. We will choose several values until we see a clear \
crossing. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f1", ",", 
     RowBox[{"2", "*", "g1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<f(x)\>\"", ",", "\"\<2g(x)\>\""}], "}"}]}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {}, {
      Hue[0.67, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVxXk41IsaAOBhaEGF37mVc8Q0e2NrfUrF96FFKi2yJJEpYykcrkkiddBM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       "]]}, {
      Hue[0.9060679774997897, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVVmdYDfwDbYmm6tLboCXSQITMe34kUiE0lGhoqLS8ohRRaSANlaRNC5ek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       "]]}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
    PlotRange -> {{0, 5}, {0., 748.9999573469395}}, PlotRangeClipping -> True,
     PlotRangePadding -> {
      Scaled[0.02], 
      Scaled[0.02]}],
   TemplateBox[{"\"f(x)\"", "\"2g(x)\""}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f1", ",", 
     RowBox[{"4", "*", "g1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<f(x)\>\"", ",", "\"\<4g(x)\>\""}], "}"}]}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {}, {
      Hue[0.67, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVxXk41IsaAOBhaEGF37mVc8Q0e2NrfUrF96FFKi2yJJEpYykcrkkiddBM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       "]]}, {
      Hue[0.9060679774997897, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVlldcD/7DxVuiqfrSv0RLSgMhv7I6H1JaEhpUpDRURkWUFqWFppa0aSEq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       "]]}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
    PlotRange -> {{0, 5}, {0., 748.9999573469395}}, PlotRangeClipping -> True,
     PlotRangePadding -> {
      Scaled[0.02], 
      Scaled[0.02]}],
   TemplateBox[{"\"f(x)\"", "\"4g(x)\""}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f1", ",", 
     RowBox[{"6", "*", "g1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<f(x)\>\"", ",", "\"\<6g(x)\>\""}], "}"}]}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {}, {
      Hue[0.67, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVxXk41IsaAOBhaEGF37mVc8Q0e2NrfUrF96FFKi2yJJEpYykcrkkiddBM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       "]]}, {
      Hue[0.9060679774997897, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVVnc4Ff7/xTUKWbdPP2RcfUQomWXe17ukMpKPRCE7q0JK9gyXSkmykhVy
cbNlJXvvPbP3tbJXvv3+OM/595zznOc8h8/UTushFQUFxe5f/D9/9jSlFTd3
w9/01zOt5SyTr+7Cqevi7oOVXNRoioIu/qi27CUOZw2XfnhOMikQ8EyhBVn0
/Q6gWU7o8In+gv9cHsxLg3MBRGszUyn/HX9+xfztkaUXjM+letzKqsWPMMX+
OejzhbgcPaxudBeeP+X4pb19f2DhIXrP4EbxjxUdn2zzBoFhM/dcjPwsPrd7
LGlD6Q3w+0w6XHi1it97pD68ZvkOJljo2i5mbeHjKYeDtpXfw0Rwf/E3iT/4
ay3vz271hYK2s37elWgMzEXeqNiwDoP+SG9/JfIxeGN+aLC+/xGK+RlsGnDM
ICaWu7MWHAE86h8P4/ix0LVvFbbKGwUNl+nmg+T/D17U8YitZEeDN3a9qn/k
NHB+6G5aUoqBPA3nJ3yvcFBm+MqS3PMZWhvUFH8++xdMhRFm0TIOuAZ/buOy
BIBq37Vtwz0eMgxxVQlKwtA9dpd7QzkBwi8V1cRIiEJKrdijdaZEcMAthhYg
cXDOYCj63ZcIWt/GqS9HS4Jq6Azt7/gv8FxqRu1Q8BJwOVdor1kngWkiz/4l
sgwsP4hJXJVIhrjZrGTWeXkoV3JaXdlPhoL1yl/FOIBQIS38SnUKsOv/4MpS
vQLmzBfeLAd/BRVmr6QIfiWgG5oQXOIlQlibl7W3/A3oL//hSJ4jgkzTlGym
qwqkpURWLWanwYTzPn3riBpoOGgYLShlAHGq2ub0K03A3RMizTOSoI2EFe/b
+A9+K1Lvz/WQwBvGXxU+uwPhx4vDZy0zgS6D5w1Hlg7kOak6PGPPgkRPvsNM
23sQs3CZY909C1SPN4RFKemBbTub5W/lbDC8dL7pg4Qh6CpRMDmkZcN1qx9R
IwLGgAqW8taYcuDc8ca0bGQCbDH1VGt9OcCJFyCJR5vBPlMB0V4hF45pAMZ6
0BymfL5orsbnQhCx3Wtb0AIKLD1jV6zz4EhuJV+MbAVxg4+U7VrzoJes3G1h
ZgOBt+6TlyXygXri6wT9/CPQk5SSW97PB563uKhcnB0opfCNPzEuAGdjiq4E
a3s4z8EcuFRdAI8j4FKG6lP482e+hxz8HYYHNpw+8D+DhMa4p4u8RUBx8gfR
Td4JNiLzhUffFEGadiLxl60zXLdsmuzcLYKFMN776RkuQMZs3y3uKgaFvgtm
kjfdAToZmb+hEqgunnp9I8UDQuPP1CeQSuCXsReFE7MXyChqyAURSmF0qCeP
TOkDrxnM1903SuEoSTw8p84Hfg24ZNib/IApseRFww++4PcimeeefBk4OOyW
Vyn4QXvmAZXgyk+grzMqFBkkABscNzwhWg7Edt+R0I5AkBcIkyOYl8Mfo+PY
0LYgeLtBXHftKAedNQuP7NHXIPW+56FpegX4+V3atRcKAUNn46vD4xVgkz8Y
W1IeAgSjRR4d9kpIedXLma7/HgYvUPar+FfCLNvcQVJMKHg1nlcVN6qCtIvb
cvLqHyE1+7tA+scq8GAfMZ+kDIfOyKuYs81VIEBAkkEl4cBvea+UXbYa0mZC
+ffkIqER4ydKga2BMqUF4dRHn2BjgYnBVaUGDFeR6vOrMcDdGTW77lUD16jl
h8O5P4N9fGb8LLkGKrXO/2QYj4VTikNsbbW1UMN8jbipkQCI32Ll5mEtTN0C
smZzAlgzrDVVStaBhVhcG0Y9EUoHaP0L4utgR+9UeoDWFzB9IbH92bUepkKS
uGPck+FbZtDQY9FGiO/WujyukgYLbAtvVE0aIedET/m1qTQQfKGKPxfWCBxN
JFEKn3SIV2BImNxthN4r8o0hFRkQ2vDGQq+mCWjPZftFGGXCi8l3azcMWkD2
ndiHiKAcyLm+mnj2XQvw3tb+GLGQAytETW1MZQsIX9TOnFXPBSt71u9lgq2A
I2hL+fyTB3qHoe7S661w6vSt6v6CfIhjaHrJqtwOZVsNDCcVigCv6GbgbdgO
kbKGKfy5RTBsKyK94tQOQa5enkSRYmDvfD3TnNYOcqI9q+x8JfA+Ul0lkKUD
dMYreVu5f8DLs61MR0Md8KdZaEg5qxzO6HrOPtnsgAxeycTt7XIoDxQtH2bq
BBPjoWhHVAEHi2+fFl/pBGJdWfJgVwU45tzudvzaCeSVpkor6iqwhI4oskMX
0BX18IUG1wBF4lbx0OsuOE/16ev4WA1EUnMNNyZ1Qb7BVgOtdC3UN1jwEHu7
4NGhhUDvaC2c0z5IfCjXDRprmwxfoR7mrAQzflH2gGbl3vbRuSbwblJvaeHs
gRfx56iEXjUBu6jDcqlkD2Q9acqSITfBzfVSsU8Pe6D2jaUiS24zED208nUb
euDZ+M/xH2qtYBPqUdYe0gvHfUMmKHragWozcfQnsRe2Ujut6E90QLRuPUVm
ZS9cLcDXvFPugEYurFLwRi+QjEL4WAo7QORrap3KvT6oXTnQ2Er867ukq72S
tx/iT2Lz2kK6wXZaaDLv2wDYLK8b2bf3w5jhwLGKhgF4e1iAhHgH4E5/oGjL
1ACUDl5aI9gO/N3pWZdpzkHgiWJ2kWUeBEx2MsspwiDE6EcIed8bgkh3PryT
0RBIJL2XlWL4BRVYjihZlhGo0R6VOdgbB6ng+jJlkRGQorHjMbwwASm0zlP/
XR8BGz/LRm7jCXiz23vRxn0EBBXMO77XToDOaFht9NwIZKQr8xhHTsJCGsvG
fvkvUDV52tByaxro+fwER2XGoGAgB+uJmYd6hfcXPZXHgBwb9PMEfh4C7sVe
5tYag0+SjK93nOeBKqTwhv6jMYgsav00tjIPe3/Iln2fx8CmxNCIamIBFofv
prZRjYNBts6Nxj4yNEcKCpU3j8NwLEaM5L8Kr/KkxI0GxkGAmOuymLoKN9uv
yP6ZHofNO3xl+s2rUE1noKJwNA6XfUOrO7FrUPoixLpQfAKoMLrJPMlrQNLe
JWaFT4D4l7JE9Y7f8JalSTjBeBLcGgpXdjQ3oegyd76G7ST00+94K3huwpSh
HRy4TQIm+PvOz/RNkCdhtXUjJiFk58ttAt0WzKkYeJxonYTBpbQArsotUHq5
1OYiPwVRBtKOgUo7sLPJ7Kh1ahp4kg0kEpz34V9u06Ojf6cBtSsVy3zbB41r
eUEk8WkwMWWp/2dqH5JD78Ue+5urpfF1oQTNA9C6mFBX9nIa5q7FLlFeOASS
lQSnyNo0MJdUDLCt/wHTIe2fmOYZkBnaf9urR4noP40/eTowA/zbt35+cKFE
OXq2XKMzM3D/mqKAYyQlwgwSXIopZ8E+7ORSUi8lSuovlnx6eRYodoJzirWp
0EwPLvVX4iyESSyWdOhikE07OaTIZQ48k1Qrr7rSILYQFxAkzAFG7TZV1mca
VHybdjksbA4eiO/xXaugQQxtvGr2mXNgPWp2d/wYLcpo0aIRnJ4DP5Lt2FoU
LVpuLHQJ05yHfKcEAc8qOvS0xs/UTnABNn6/eNIvRY94pq7TbkkuAONpYup7
PXrURHU8zR0twFWN07R23vToLApeC7q/AIaf+h6HN9OjgeKP3kmvF8BFWqcl
yoIBXclKiR1YWYDe0NhtnwRGxPqpflCpcBHq8ZuDmpLMKNue8Q67yhJcMq48
ee8hG2qOxrqQdJaAdt0n8MCTDc1Uc8ZdNV+CraAnNYWRbIiTQ2jxsdcSxG90
1zo3syG/CuWXFflLcJJFjotdGot02Lxybc4s/91XurwR+pNoL3cN+2N/GcYU
6Ugd9f+gBLdHC2K6qyASJGtXE8KBxMqP7xAe/O3pu8j90G8cqJw6lWbUbBVi
sixSnZo50FjwFC7YfhUSCwUIAcc4EU/8A935oFXoFsRql/hwoujq29UJpaug
nU2gCnI+jUJPSMWynVmD4Ukx63UnbuQbd/DfBnkNCjPpGA9HcYiiawyVuq7D
cx2pgLCvZ5HAcwtnbeFNeJie5MFdJ4KmNiN0GH5sAaZX16xURhypTtt4hD7d
AXe3xfAuc2mkMRUiwsOzB77mpMdj7HJoocrUu560D+ryRP1dZkCirL3cSkaH
QCHtk6347iqih02T4b+9ZFYdYJMpVEY3lvS2z9ylQPY4OvozBBXUX2lOqXee
EkkafGTgJt1C+YHVhrhNSiRt/PHX6W1NZEHjONbaSoXsA4TjyjzuIDMHt3zG
aAwa41iOSmfRQRctRVrVTaiRs0h9SUzzPdTGdp7BUZYGyflyW/VRGaCSb76f
zmNoEROrcZ4vGCE3SmHN5hFadPb9iagPL00Q/bDrTds8OpSFdA+YXpqh6RS+
sDj3Y4gpNo1+2uchCjvHQV109zjifWKXf9BhiUKiLepMcPTI+9SYSxqvDdIL
e9DKOEuP5ux1M9z8H6Oda8m7cWUMSJSt9nnbTTs0OX3VuZLAiPKfH/vnDtVT
lKgofrrF5AQyv+EJTGEOiOTvyGp5gQnJms7IdOCeI8JdMzXMJhOq5//7j4od
kfRwApHQwowCp2J2/33nhCKFPpFa1FhQGvNOvJO+C/IqD45UK2JBctU12jxW
bujW6bvJjfysqP9uDvuhvwe6YlunzxrEipbLm8Z3I7xQHJcpf/MmK1KTVqyn
2vVG/FVfwzX02RANw3V7CV5fFHKhUrizjA3RV9BHSqm/RBbr1B0Nwlik/+6F
k3SCHzLN/o0LeodFMbWZZxSX/NFj3zsHqu+xiGIixVVg3R853snrY/yARdn1
/hMsu/4ocNPxbUg4FtkkGUzMUQegb7K7+xGfsahIjTM5mSsA7VYc9aakY9Ed
Jkl1LfUAFNLJGFxdh0VUx+qbnDMCUPSXJ1YBDVjExXBM0y8nAH153qp0swmL
nisozoYUBqCCUyF7Ta1YpNY7p0GqDkDDelirrh4sYvu8SrM+HIAEJzmUJiax
6IMI7lzOCQISy3PlSZrGoirls7OtWAKS8x/afTj7Vy+kFJM5CEhd8HPW/AIW
MXl5xIn8PZ0Oj3A8a2tYFDhx3qwAT0DuCj67OetYxJ5dWj90jYD8T0x0P9/E
Io7C10pUagQUmfnl9c4OFv06reKipUtAid7UlsV7WNSuYSXl/oCA0v97eNX9
AItCLc7RfDUjoLwztdz4P1iEb01Y7LQmoLJ1gd2jIyxaXSXPHtkR0P8AcqWN
yQ==
       "]]}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
    PlotRange -> {{0, 5}, {0., 749.9999540816334}}, PlotRangeClipping -> True,
     PlotRangePadding -> {
      Scaled[0.02], 
      Scaled[0.02]}],
   TemplateBox[{"\"f(x)\"", "\"6g(x)\""}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f1", ",", 
     RowBox[{"7", "*", "g1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<f(x)\>\"", ",", "\"\<7g(x)\>\""}], "}"}]}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {}, {
      Hue[0.67, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVxXk41IsaAOBhaEGF37mVc8Q0e2NrfUrF96FFKi2yJJEpYykcrkkiddBM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       "]]}, {
      Hue[0.9060679774997897, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVlmc4Ffwfh608GQnnScg4ZBRCUUr4/jJDWRmRyLFVEpFVisxDSRTK3iJb
Eadjc+y9ZZOtQ9n+z//F57rf3G/v6/rw4R7pWVNRUFBs/7f/M+45jva8lZfC
v6fpreLfVF2t7cbeMMIaQ5vjKA071x2Fw3qCHxZrDz9GMMU2p/AKTBGl+fQD
znCUoalpaSxdIY4YxnsE6wGa/3QyMp36riC2avX60NYHTMtXbU3cSQqjTPEH
e/2+YNXxa7F8rE9BIJ3u0s6uP0jvfXUNODOp8EDe9eFf3mDg4HAvm+BcVCjq
GU/dUAqFbLbi/J+aZIWd+zdG1m3fQOG70XoZ9x2FRMqR4L8qb8FxP/NDeBwl
KLe+FfzTHwHfLE7sJ43Rwny0WtWGfSToFhJPpWKOQajVvil5Nwoe9A4/cz3D
CpKSRVvrYR/A3c9Pz9qADbp37SLXeGPgRNXom2bOU+DWwCO5WhAL9G5bXPbX
sMD5rqd5WekTnCmwyO7UPA0EsxDbpd44qCOecy4uEAKcCKJetE2Alm5zNyF3
EaDa9Wzf8E4EHo7db3Kp4tAzbsC9oZIEA+aUPAFx5yG9XvI+mSkZJHYrKHqx
0uCew1D2uz8Z6P8U+EeNXQKNiFna34kpMDo3cU5v8ApwuVfpr9unAredlmcU
Rh5W7n5KXruQBtyBe5sbagiISk/XVnfToPfbOuXDM4oQcVZPYbU2HX5HBvK5
iymD1fFzoSthGSAypxB1x0AV/hmeFF7mzYIBrhNeRE5NGCBWui7NZ0HVh4uO
LWU3ITs9umaxIBsG71QO467pgJazlvmCUg7U0V/NIGneAuzts7m/GHPBefM9
0+5vffgtT7M735sLbCTa5JwCQ3hPV/5+zjYPihpPt3G7m0DxUw1nF/Z8sCPo
ZvC/NIVPCzIcZO98eHkx6pxUqhk4drDa/lYpgK+8EhMv4izASImCyTm7APa0
CoOoBnCASpeL15kKIY/+mlo71gpYPzVSrfcXAg+ZUuPNmA3sMpVmOckVQbH/
E3FBfTuYfpmis5ZYBK5OLg6ag/ZQavs8ftW+GEQ4P5x9jXkICUP3VR61FcOO
wt6Nm02OEHTTeGnlQgn0K8nQrKs5gYmUtOzKbgnIZe7X2J1xBqV0vomH90rh
0ilRtzlBFxDjOB60XFsKB/4JkS5iT+Dg4FfvUthX6MuMKzU0cIMkUsLjRd4y
+LxUsFbO6QUb0SUiP0PLoB4nf8r4pTeo2jZPdW2XAYuftjz3xjNYov5rUN5d
DlOsktouPi8AuhiPf0HfgfxApSJL8yVEJPI3JuV+h/6bGkQTHl+4LK8lGxxY
AUO9Wmci+/0Az2BF9t6ogJ6oaWMdwisYG/TIcbKoBHOm95Urn/3hlVsaz+2r
BBg2cS+98ikQOvL2qIRXfwC+8lHOaDceWIHO7Jg4ETjj2XNfbITCVaFI2UAr
ImTGXmTr5XoNrzeyyJ6dRGhk9B7zVgwH6be91rjPVaCs4tBKPRwBZu73FEcm
qiCjO+u1P/4dBJov8hiyV0NVknaCGoqEoXOUA+r+1cDEZuVNLI0CH5KYxnnz
GlhnbK5dHYiGzIKvQp+jakBOzShxLCcGuqIVqQVbaoCK7Grj6h8LAra3K9iv
1EL9V4oXbcqfgET9SpwCUwdmqTaBMfsJsLHAxOCpXgcyoTqiHP91x90VM0f2
qYPuk60Gy7uJ4JSYlzi3VAeqkhJDqtTJwCY/zNpeXw/MlQJrLudTAQnYrF7f
r4fxIXVCUU0q2DOsN1dLNQCf5TRX3u00qBik9S9NbAC3H8rOv0PSAed24W+c
ZyPcO4DWeyxZ8CUvePiBOAmsb+KJAZ+/wALrQqiGBQnSZFPwaeZ5IOymoXAm
kgQepbKnEEM+JMoxJE1tk4D1bTIW6vMhoinUxqSuGb7kVODYbxaC29SbdTXT
VmDP+CYakFgChapryYJvWkHbdHIgn6UUVrN09KmrW4FWZjLJ8lUp2DmxfCUI
t0F6HI71geNXMNmP8L5IboPVDWNZPYMySGBo9mNR6QCpTeKxaqdKUJD3Mn1h
1gGB0ezV2buVMOIoenH1aQdoWAFBJYgA7F342ZbsDlgp2WKPS/8Bb6NvqAcx
d4IzdWDEsT0i+Am2MR0Od8Lz2nwfXfca4Dd6PvdwsxPIqVfl/zTXADFInDjC
1AVcH7Olg7G1sLf4+nH5tS5Ymy9i82mpBddC7R7XjC5QWF4Oa5eoB1vojFly
7gap3DZvEcEmoEj+Uz6M74Yg35/RpgFNEE3DNUJK7YYzDxIWA+eboLHJhier
rxv2vVvF2vNIcEZ/L9latgcCYtSnFDVaYN5OOGeMsheKJrc1e/Pa4UXzjdZW
zl5QObq8+IG5A9jFnVcqpHohPdutolm9A66TKyQ/WvcCD6uwR1NlB2Q90ysx
auoF8ZW8GvGcTnCIeEboCO8D+uX9QtGUbqDaTP75I6sPeOs2BUKnuyHWqJEi
r7oP/p5tYn4m1AMkLoxS2EYfaHB2d7Lm9IBoRmaD+u1+qDgpbMpL6IWl790d
1bwDwBx9P0PtoB8cZ85OFX8ZhE6kVneOPALjZoNHq5oGwatLxO2I9ijcGggS
b50ehOEsh5j4z6NwuXnOY4ZzCFIuRODYbceAuiCNmS1wCCYW/CXR3E+I9uZT
eGo+DNybkXzBARNQheGIucI8CrOTxopCO9MgHdZIUBEdhQpJsbZl6RlIp3Wf
1lUdBaE69yp+pxkI3e6TcPAeBXFVjSd9czNg+DOyPnZ+FNSv6552GpmFhWzm
jV3iGPSr0tyvG5oHer5Xwj8vj8PhflpVpfgyNMq9lXiuMg6E11h6ZpdlCLgd
L8OtNw7js5eTW74uA1X4N7U798chcOAUQ4DiCuwcLNn2x43DnkRMLdXdVVgc
Mchsp5oAvojfBxe716AlWvgssWUCKKa/4BJUyRBSLH3efHACcmN1LSsfkeF6
x7UrBzMTQJ4QKjoRQ4baf0zV5Q4nYPGDwYzrEhkq3MLtv52fhIEBWbbtqA3I
1d/Oyn8/CUz2Y5XiG5vwmrlZJOneFJRHGVU/HduCMhnuEi3HKdD96vZeFbMN
02aPYM9rCsTbX/w1v74NV3Mx+kYfpiDzBlxwKdqGeXXTZ8fapqDHoUGNL2wH
lPyW2z2uTkPhe8xYk9YebG0ed9VjmwG9ewxHzWgp0Glu3OHh6RnwvKJ3MkmQ
AmkpFwfnnp8ByyvFxYwqFCgt4nb80ZszMIcjUJm9okB6EkkNBL8ZGNH7RFqk
oUS5dhc4RddnoMmI9pB0jArhhvV/ULfMQpVPR7o20CD6jxMPHw/OwqGGpLmY
JQ0qNHHk+jk7C3aeakZSgTSIeijQo5xyDgaMlu2J7TQodaBc6rHMHFDc0OkY
xB1Bs73YzLHkOTBilr/D+5YWOXQshZd5zMOvH5SXU5joEGu4BwgHzsOr/gKq
LRk6VK5NuxIZOQ+K0ynCnhZ0iKGdV9Mpbx50JBKmaEvoUE6r3hHhmXl4RBId
VjajRyukbx6ROr8gk8HW166MAT2ue4V7JLwADU4lPnsRTIhnWpX2j9QCXNGo
Uz4kMKFmKrpsb7QAW/6k82KLTEgQha0HGy/Ayk+dHhrl42iwPOpFKn4BcApv
HhX9PY6u5afHD64uQGbv4w58ETNi+dg4pPRtETbKynyUpVhRgRPjLXb1ZfjF
eZldzu0EaonFeOQaLsMFVcUEocgTaLaWM0HRahk2sAazYoUnECfH2cUHPstQ
7rw1F7pyAr2qUvGrKlmGk3Yr2E92bMiQ1afIgX8FRhPMMqhwJ9FO0TqmcncF
hpyDNtQdOFCS1/0FSaM1OIqtoXzbzY0kiXRbgXfXwFovUNDwDzci0mQe+Wm5
BgxtT5UvcfCg8bBpbJjTGlSK5capmfMgnsS7Rr+C14DfmG0yb4kHxdZq1yZV
rEGDt8CSNi0WRRyTjmflX4drQwV6KZJ8yDdhT3djaR1y/h59vZd3GlF0j6MK
TzKMWkV88lU6i4Se2Ljri2yCTplGsJC0JJre/GDIUPkHvnjMugSclEYaMw7P
Ih5vATOznX/S5mWkNR0uysOzA4qbT87ecVZACzW4F425u/AB10pK51FE4ix9
3Erm+9BbyabNnaGC6GHTYoR8AKwv908sGaojtWWTv/wGFMhP56iFXuNNNFBt
RWkiRol4mqtU07V1UUlQrRl2kxLNx1IPbpJuIZsjruNtbVTIV83UyqzSEFk6
e5UwxlIjSZ7FIG6CMZKwFW27YUGDvl74d7h0xRS1s4oxuF45gv7ibTL2De+h
7198P4pR06L44sl3FrI45EUpotMySos+P5cd7XO0QvQjntcdi/9BbdjvXm9r
bNBMOl9kgvdRxGzJJYM/aY8iz3DQlBnQoVR9o+e6pPsoPNamwQJLj6Ie+U+p
ejoik8i7bYxz9GiEUqr9QooT2lJO204gMKCPIS7GbeCMpmYU3asDGdHz0eBo
hgEXlCx//lSrxTGkcQuj8T3HFeX6u7LYnmNCity46nivpyjQwFKTepMJLYj8
94+MPdDFkaSswNbjKIFeJkXf2wtFn/2Y26rJjNYr3GbvRT1DPsSwaM0yZhRz
XO6b+7YPunnKII0kwIIIppUp3ZdfomuODXdYglnQuL+F495DX5TAhRNo2WRB
5wiffp1r9UMCNRnvte6wIkncnq+1gD8KP1ct0kVgRZcmLAoi/AKQDZmms0kE
g1CGOYM9SxDCFfzGBr/BoFJb/lsNkcHoge+tPY23GERx9+F0zsdg5HqruJ/x
HQYJOKwXvksORkGbrq/D32NQ5w+2o9b5wejLle3dD3EYREW9EcXWEoy2qw77
0j9jkMXV2dsl1CEovIsxrLYBg4zo/lWadAlBsSkP7QKaMOgPY3HhqmcISnnS
pnS9GYOC6rksD16GoFK28J3mNgy6rV0ewBsegkZMMHbdvRi0YKE04pQTgoSn
OJQmpzDo5ajnoPZMCJIs9uRJncEgq04Ky8dLIUjWf3jbeg6DtDROSkSSQ9AN
4bj8XwsYNEuwfTNKiUfO97E86+sYFH+32MWHB4+85V5uF5Ix6PfpkX8/C+KR
/7HJniebGNRo6L7dL4ZH0Xkp+K0tDBrc9Am7eBWPkl/Q2Jbv/OffEZC3UcSj
z7rWit57GGTAnycZrY5Hxfz13AoHGESuk7Nr1sEjAllo+/AQg2pqfk0dGuHR
/wAMEYyE
       "]]}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
    PlotRange -> {{0, 5}, {0., 874.9999464285723}}, PlotRangeClipping -> True,
     PlotRangePadding -> {
      Scaled[0.02], 
      Scaled[0.02]}],
   TemplateBox[{"\"f(x)\"", "\"7g(x)\""}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output"]
}, Open  ]],

Cell[TextData[{
 "By expanding the range of ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " values, we can obtain a graph that provides fairly convincing evidence \
that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"C", "=", "7"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "=", "3"}], TraditionalForm]]],
 " witness for the assertion that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "x", ")"}], TraditionalForm]]],
 " is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SuperscriptBox["x", "3"], ")"}], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f1", ",", 
     RowBox[{"7", "*", "g1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "20"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<f(x)\>\"", ",", "\"\<7g(x)\>\""}], "}"}]}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {}, {
      Hue[0.67, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVlmk41XkDhi0hQpYZQ2U7jj1y/GXn95QiigohVOMMhyTbpLKmaGSk1AgR
olKKpKRUJMkesoQo6hwlS5ElS/L2friv57o/Pt9uRWaAvRcPFxdXzS/+v5lR
TH6GZ4Y591YpdS4uGqrbFbY5K4QSc1EFnmhBGpZqKmIUFOKJXUSYgZokDZmV
ifJ8ChdJ2NgBl2kVGvzMQg5+l88nA9TWvowdNNzrGLg6ZVFAruzhcB11o2H+
wLa+Ce8i4uL2V3UMi4ZNL88pz3TdJeree+q1ImloX/BJHpcvI1atW/UGC2g4
XCun87X4EYnNly1zLqNh1X8djWMWT0jbMV957hoamBrgHfF+SrQePmX86Kfh
aMGKsm9dVeSVN/N1gZQSBHo/qI7J1xOZjT3ez88qobuyPGR0qJ4o75IeEbus
hJt5ac9HihtI1IMfHVfuKMEu2G7fsEUTuf5zKTKzTQkpgo9SPnm3kIq8+cQ5
GTpKjtgE/y3dSuQ2+RclrKXj0rCBzGREKxnevSbMl9Dh3yrh/W3zK+IQE1wg
zqJD4lIdz0RXG9n9VuyL/AM6FkRL8wNN2wm3HbNKp4kOzvErO8YvtxPdP2NO
XHhPR6l3VNbX/R2kejHKe6+IMlwpPeMvC50kToulJbBfGTkN2UEj8j2E827T
xDGGCqbS7mv0n+4hJzJ3Z0TbqcDSu5HdNtdDfntjsHL6gApGeb/vetT+hqjU
MKfMbqjA0MzOOD6uj/xrNP5boIoqWot+8Kh+7ScFgt13XYzVIEEE94poD5DW
ruzHCvvUYKKSbBznOUD0l4eKBsSq4cxU/mTYqwHSfypI90qrGvTOdXoxb70n
9J7Z9vgAdRxrWGvD2McmHYztxx3qNHCj+IHKrQts4u+4ZUxoRgNtaRt5lZvY
JK08XcmNrgm6t8sTaSMOKXXfc7bhhCYaeGO1uSQHSXpm13M+q7WQMuuVaKn5
SJzyzlwdH9MC6KyvWxZ/OdPg6FNlbexfMdFYRX0ietbHU4z2auNJD//J0suf
yPUkIQe9V9pgHtb9nhk2RIY6A9d6Pl2H20XxvX7aw0TKzUy3+50OhiWGT9t4
DJO33RrpSj91oHrYxlwteZi8Mfp8/5ksA5dNV+Sw54bJCkbL8Pc9DJyvP81y
fTFCqBeLR3Z/YOAw++yElfsY4RLuSHRd0MVdy/Fc5bNjRFy6pFBQgcLX/B2O
vFVj5OJ6Iii5mYJPoPiDCtUvJF3Hdpd+EgXXxfMR6ye/kO3f+QKaNPSQvaIx
RnzzOJmy65G6HLQe5mbh7tF7x4npSzs/zUvr0eevuf7rkXGin2B9Urp2PaTb
Ej423RwnXTtfsGXk9HEubZv1KbEJUvnmv+iaVn3EKDeLLvVOkFhm+HUda0N4
k1cXR4MnCU4OySTHm4Ard+ZRb8IkCT6Um6dWaYK0ZWv6Gq5OkvXpVrnq301Q
V8+Sy389SZIrwwqCWaZQc/yR62U8RXbMpxzRsjHDkI9qwTvuadKlbbIhX4XA
93xkRWvSDNl+Yj/lm7EBPNO5/U/zZ0i38ZzX5/INSHeu4yqqmiECBzKGrg1s
QMMaSYvEqRky9FLjWZfKRmhev1Fr7fKdRL/7OUUv3YjRx+2tVfKzJJlRI5k6
YAH/QXV2ye05EtuumOTNssTA3p7lz+rnyJUXtgJZyZZw6D6l/ZIzRwwjbXiV
n1vCsPFT6OCqeWJof/aWsqIVeIuviUnFzZNhdf2bcwNWSItQND+yb4EUbAyp
1Qy0xjNJmYtGYouk7nZW+b3mbdBLrKvYrLlIAkoF9eIEbJHHf5Sz03KROK8T
NS+BLU7PvV7nG7FIfP99or2mxBZO/ck16UOL5FN4VoBmth2Gb4pNLVT+JMFL
oQcsLHZASDFWtd+QC8sTB02k7OxRZ3puXdRmLpiP16z+zd8e/7hkGcjac+H3
nPdjpmfswZP00MrtABfMPJPerWyxx/zPUe+uTC5EPgnSqLB3wEjfrhstPNxw
+F2f4cR0RFOaqnplEzcK/FxoG6844d8SPca+Hm7IjH526apzwpbWDUY/B7nR
FKmgk/HFCdUC7tamS9y4tMNGv8jYGU8OJ+1/yODBwpL2mxWdzih0nMu/k8ID
fNTeXCyxG2fEGjVy/uSFcWdGS9hdN5QZyN638+fFhY7RvJr3buDsDSA/wnkx
w+ZKtRV3h0mhpKNzKi/8xZnOIkHuGLJ2jxRp5kVReWqwC7UHFjFjLaEmy3B5
pXW/2fO9mJ1eGWIvxYcvl6rnry33gJIsc2lJiQ8flpdWKdI9YLepJL6QwYeA
I3X+5cQD1867ZC235UPm1i0Vjkc8YL8up7Yihg/JbuFWfEMeKPTRXaU5wYfZ
v0d8olqYYPY6PuVt4sc3p9cyjg88IZTx/mBQDz80ehxfub/2xF1X/zX9H/nh
ZZIT98+0J3jfxIU+4hbAvnPJBmZ6Xrja/YgKMhAAl1zEBaN7XvjYqXDjXa4A
PpzhbY58wIJv62hSWehybDuc7nynxwdBL2KZAapCuJksO5916iDkOJb8M5QQ
+kZssqsLD6KRR/BmBISgmp3RIdR+EMpInIjf/cs/G6vPyfqj59GF6KsJQjhY
Ei6y774/NtzJy+r5KgRWiJur+3AAxDPq3lg8XIEGPnlOpX4QigOFHaStRXDI
f2JZy9jfaEqXDC10EkGan6B6Bv8hfKxelb3RUwRxVr5JEfKHsEpGfcTvmAg6
WY9tj+08hNhnm2Oe3ReBlVhizMnSQ3CSOHbPlyYKU4MI9qXYEMzfm5AsXxDF
g9ULdwwYR5ATfmBYx1kMckF8LPnmMOhUCs7G7RHD0760t1HDYahcdoOv/y8x
LCkE9n3jD8dAIkchMVAMoqm1idIIh9zlPc6f48VwclI1ye1eONKrt1fnPBHD
drLmUk1mBM6L6GVJ0MTBLtjwm9eJKJzI/rFzalQceqvCWnUtj4OrfQBPwiQx
/PqMn9/Tk1A5xDrqqPE77t28nf7WLwGc6VSnFeVS8As5yE3VJsFm0DfyfJA0
zCvEjbtTkmHHSdKUk1sF7jLn0ve9aRh+zoyuK1wND7OhiibnTGiLv5a12CeL
7wm+2+o9cyBEpj36JuXgmtbWPmd4FVZjrt9puxRwvNk0LDjrOrqrPLld1yoi
0EHjnbXdLdw/Vb1XYVoRE9XxOrski8DiCxlobqZh0SHYSPxFMf4KDr8vnK6E
ygxTx17BEqzz1mze5kGHTwiVcDCoFC0Sa1eEGCnjDEutgdeiDI9vn8hYy6uC
9rfFD9uknyCcW2NH01sVsPVZV5tYTyHUF7bFv0QVK6NabOuDnmEwTzE5O0IN
H1O25HzWfo5kNZllZbvUgc0fcn/XfYGkdFath4IGyPY1jsG6tXBN3tMs/EkD
tYWfkuWs6jG76dpcdoUmxH++56cKGsEe3Hi0Km4t7rBZRtJCzcg1Y6x+6aGF
kb9pzqF/tqLwZIi4t5Y2iqICn5MHrxC366+tvNPayG/8uG5Buh3r+3Ly416u
wz7hra4LBR1IU88ofLlVB39Ope5JNXqNY5WJaVvLdNDj6xduvtgF29W7rjXQ
GfiiFnbfqaUHG/xr3cTjGZBmZHv1p/Qiew2T3jTNAI+0cPVsxlvQn19PsXPT
BdPQoGM+uR9JWlUabRW6+MO+61tR0wBYk8te1WtQoK/UjOSZeA9m8TeF+LMU
PK/t1jkqwobfCYcfNucoPJQvdzklwUaIQ0mX8H/Ur457ybr4BxunpkPOJKVQ
GFiy1KtQZOO20dxCaiaFXP3OFAl9NuaeLb3Ou0VB+4jW6Y972UhqE06srqVg
OGtWY1LMRvqVgz7/1FNwuXS70aeUjSuHmi22NFKw9HUuS3nMRqlU0nxjM4X/
hnJtp1+w0ecq6dPeSaGY4eZe/oYNVbaMxQc2hUBheXroMg50SsLkrg5SeEW7
VFoiyIHxyd45r08URmdSdCdEOdimmnnn8zAFXTPnT34yHAQfUJCbmKAws8zU
MkCbgwjT43N3Jyl0Ng6o3KU4OCnyoePQNAWnVXkT04YcpBVdSZidpWB7j705
2oKD3Ohl3o/mKZjdiW2p2cLBrZ1eGyN+UGi8mGohasdBCa1G1vznr7/1OrlO
DhxUTKrMLS1RqE71HMl24eB/ur63Bg==
       "]]}, {
      Hue[0.9060679774997897, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJwVlmc4FQwfxu1kZTwJGYeMbDr1aOD/zwyFlEQiJ7uSiJCiZD2l5KE0bBlF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       "]]}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
    PlotRange -> {{0, 20}, {0., 55999.99657142863}}, PlotRangeClipping -> 
    True, PlotRangePadding -> {
      Scaled[0.02], 
      Scaled[0.02]}],
   TemplateBox[{"\"f(x)\"", "\"7g(x)\""}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output"]
}, Open  ]],

Cell[TextData[{
 "It is important to note that the graph above is not proof that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"5", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{"4", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"3", "x"}], "+", "9"}], TraditionalForm]]],
 " is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SuperscriptBox["x", "3"], ")"}], TraditionalForm]]],
 ". A formal proof must follow the model provided by the examples in the text."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["A Second Example", "Subsection",
 CellTags->"Section2c"],

Cell[TextData[{
 "As a second example, consider ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    RowBox[{
     RowBox[{"3", 
      SuperscriptBox["x", "5"]}], "+", 
     RowBox[{
      SuperscriptBox["x", "3"], 
      RowBox[{"ln", "(", 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        RowBox[{"2", "x"}], "+", "1"}], ")"}]}]}]}], TraditionalForm]]],
 ". We claim that this is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SuperscriptBox["x", "n"], ")"}], TraditionalForm]]],
 " for some value of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 ". We want to first determine the smallest value of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " and then find witnesses for ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 ". We assign a name for the formula for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "x", ")"}], TraditionalForm]]],
 ". Note that the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox[ButtonBox["Log",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Log"], "FunctionLink"],
 " with one argument computes the natural (base ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]]],
 ") logarithm of the argument. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f2", "=", 
  RowBox[{
   RowBox[{"3", "*", 
    RowBox[{"x", "^", "5"}]}], "+", 
   RowBox[{
    RowBox[{"x", "^", "3"}], "*", 
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{"x", "^", "2"}], "+", 
      RowBox[{"2", "*", "x"}], "+", "1"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", 
   RowBox[{"Log", "[", 
    RowBox[{"1", "+", 
     RowBox[{"2", " ", "x"}], "+", 
     SuperscriptBox["x", "2"]}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We could proceed as in the previous example and display a selection of \
graphs comparing ",
 StyleBox["f2", "Input"],
 " and ",
 StyleBox["x^n", "Input"],
 " for different exponents in order to find a likely choice of ",
 StyleBox["n", "Input"],
 " and then explore the coefficients. However, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s ",
 StyleBox[ButtonBox["Manipulate",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Manipulate"], "FunctionLink"],
 " function provides an interactive approach. The syntax for a ",
 StyleBox[ButtonBox["Manipulate",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Manipulate"], "FunctionLink"],
 " is very similar to that of ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 ". The first argument is an expression involving one or more variables that \
will be altered by sliders or other controls. In this case, the first \
argument will be the ",
 StyleBox[ButtonBox["Plot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Plot"], "FunctionLink"],
 " function. "
}], "Text"],

Cell[TextData[{
 "Following the first argument, we specify the variables that are to be \
manipulated. In this example, we need to modify the exponent ",
 StyleBox["n", "Input"],
 " and the coefficient ",
 StyleBox["c", "Input"],
 ". For the exponent, the variable ",
 StyleBox["n", "Input"],
 " should be allowed to range from 1 to some arbitrary maximum, say 20. Also, \
the exponent should be an integer, so we specify a step of 1. Thus the range \
specification for the exponent will be ",
 StyleBox["{n,1,20,1}", "Input"],
 ". Note that the requirement that we include the step of 1 is the main \
difference between a ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 " and the ",
 StyleBox[ButtonBox["Manipulate",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Manipulate"], "FunctionLink"],
 ", which defaults to a continuous range of values. For the coefficient ",
 StyleBox["c", "Input"],
 ", we will allow it to range from 1 to 30 continuously, making its \
specification ",
 StyleBox["{c,1,30}", "Input"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f2", ",", 
       RowBox[{"c", "*", 
        RowBox[{"x", "^", "n"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "5"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "10000"}], "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<f\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(cx\), \(n\)]\)\>\""}], 
       "}"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "20", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c", ",", "1", ",", "30"}], "}"}]}], "]"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 1, $CellContext`n$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`n$$], 1, 20, 1}, {
      Hold[$CellContext`c$$], 1, 30}}, Typeset`size$$ = {421., {111., 116.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`n$1333$$ = 0, $CellContext`c$1338$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`c$$ = 1, $CellContext`n$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`n$$, $CellContext`n$1333$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$1338$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Plot[{$CellContext`f2, $CellContext`c$$ \
$CellContext`x^$CellContext`n$$}, {$CellContext`x, 0, 5}, 
        PlotRange -> {0, 10000}, 
        PlotLegends -> {"f", "\!\(\*SuperscriptBox[\(cx\), \(n\)]\)"}], 
      "Specifications" :> {{$CellContext`n$$, 1, 20, 1}, {$CellContext`c$$, 1,
          30}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{464., {168., 173.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that the ",
 StyleBox[ButtonBox["PlotRange",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotRange"], "FunctionLink"],
 " option is useful here. Without it, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " would continually resize the graph depending on the choices for the \
variables."
}], "Text"],

Cell[TextData[{
 "When you first execute the ",
 StyleBox[ButtonBox["Manipulate",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Manipulate"], "FunctionLink"],
 ", you will see only the graph of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "x", ")"}], TraditionalForm]]],
 " since ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "\[CenterDot]", 
    SuperscriptBox["x", "1"]}], TraditionalForm]]],
 " is too small and lies along the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " axis. To inspect the values of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]]],
 ", you can click on the small plus symbols on the right of the sliders."
}], "Text"],

Cell[TextData[{
 "As you use ",
 StyleBox[ButtonBox["Manipulate",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Manipulate"], "FunctionLink"],
 " to explore this problem, keep in mind that you are searching for the \
smallest ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " for which ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "x", ")"}], TraditionalForm]]],
 " is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SuperscriptBox["x", "n"], ")"}], TraditionalForm]]],
 ". So once you find an ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]]],
 " that work, decrease ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " and make sure that no ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]]],
 " will do. You may need to expand the domain to be sure."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.3 Complexity of Algorithms", "Section",
 CellTags->"Section3"],

Cell["\<\
Section 3.3 of the textbook emphasizes worst-case complexity of algorithms \
and shows you how the worst-case complexity can be deductively determined. \
The textbook also mentions average-case complexity and shows how to compute \
the average-case complexity of the linear search algorithm (Example 4). \
\>", "Text"],

Cell["\<\
Average-case complexity is typically difficult to analyze deductively, but is \
still very important. From a practical standpoint, average-case complexity \
can help differentiate algorithms whose worst-case complexities are of the \
same order. Also, algorithms that have very poor worst-case complexity may \
have reasonable average-case complexity, provided that the \
\[OpenCurlyDoubleQuote]bad\[CloseCurlyDoubleQuote] inputs that produce the \
worst case are rare.\
\>", "Text"],

Cell[TextData[{
 "While average-case complexity is difficult to analyze, average-case ",
 StyleBox["performance",
  FontSlant->"Italic"],
 " can be computed fairly directly. Recall from the introduction to this \
chapter that we distinguish complexity of an algorithm from performance of a \
function. In this section we will see how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can be used to analyze average-case performance of functions \
experimentally. We will use the ",
 StyleBox["bubbleSort", "Input"],
 " function developed in Section 3.1 of this manual as an example. Our goal \
will be to produce a graph displaying the empirically determined average-case \
time performance of the procedure. "
}], "Text"],

Cell[TextData[{
 "First we review the standard approach to timing functions in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". The ",
 StyleBox[ButtonBox["Timing",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Timing"], "FunctionLink"],
 " function takes one argument. It evaluates the expression (e.g., a function \
applied to input) and returns a 2-element list consisting of the time (in \
seconds) used and the result of the evaluation."
}], "Text"],

Cell[TextData[{
 "Here is an example of the use of the ",
 StyleBox[ButtonBox["Timing",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Timing"], "FunctionLink"],
 " function."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"findMax", "[", 
   RowBox[{"Range", "[", "10000", "]"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.02631400000000000058419935555775737157`4.44078678363391", ",", "10000"}],
   "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that, in this example, the time that is reported includes the time \
take by the ",
 StyleBox[ButtonBox["Range",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Range"], "FunctionLink"],
 " function to produce the list of integers from ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox["10000", TraditionalForm]]],
 ". On the other hand, the ",
 StyleBox[ButtonBox["Timing",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Timing"], "FunctionLink"],
 " function does not include any time used in generating or formatting \
output. This is negligible in this example, but for functions with lengthy or \
complex output, it is reassuring that this time is not being included."
}], "Text"],

Cell[CellGroupData[{

Cell["Average Input", "Subsection",
 CellTags->"Section3a"],

Cell["\<\
By average-case performance, we mean the average performance of a function on \
a random input selected from all possible inputs of the given size. The \
particulars of how the random input is selected is a necessary component in \
the analysis. It is natural to assume that each possible input will appear \
with the same likelihood as every other, but it is important to recognize \
that this may not always be the case. It may be that, in the circumstances \
under which the algorithm is intended to be used, some inputs may appear with \
relatively higher or lower frequency. \
\>", "Text"],

Cell[TextData[{
 "In our test of ",
 StyleBox["bubbleSort", "Input"],
 ", we have no particular application in mind and so will assume that all \
inputs are equally likely. In order to generate a random input, we will use \
the ",
 StyleBox[ButtonBox["RandomSample",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RandomSample"], "FunctionLink"],
 " function applied to the list produced by ",
 StyleBox[ButtonBox["Range",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Range"], "FunctionLink"],
 ". The ",
 StyleBox[ButtonBox["RandomSample",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RandomSample"], "FunctionLink"],
 " function applied to a list produces a rearrangement of that list. The \
following produces a list of the first five positive integers in random order."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RandomSample", "[", 
  RowBox[{"Range", "[", "5", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "5", ",", "3", ",", "2", ",", "4"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We can apply the ",
 StyleBox["bubbleSort", "Input"],
 " algorithm directly to the result and time how long it takes to execute. \
Note that we obtain the time, without the output from ",
 StyleBox["bubbleSort", "Input"],
 ", by accessing the first element of the list output by ",
 StyleBox[ButtonBox["Timing",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Timing"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"bubbleSort", "[", 
    RowBox[{"RandomSample", "[", 
     RowBox[{"Range", "[", "20", "]"}], "]"}], "]"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input"],

Cell[BoxData["0.00198599999999999991817656308512596297`3.3185791574389865"], \
"Output"]
}, Open  ]],

Cell[TextData[{
 "Since we are after average-case performance, we'll want to execute ",
 StyleBox["bubbleSort", "Input"],
 " on some, say 100, different random inputs and average the time taken by \
each execution. To collect the 100 times, we can use a ",
 StyleBox[ButtonBox["Do",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Do"], "FunctionLink"],
 " loop to repeatedly execute the function. We use ",
 StyleBox[ButtonBox["Sow",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sow"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["Reap",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reap"], "FunctionLink"],
 " to build the list of times, with ",
 StyleBox[ButtonBox["Sow",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sow"], "FunctionLink"],
 " applied to the result of ",
 StyleBox[ButtonBox["Timing",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Timing"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["Reap",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reap"], "FunctionLink"],
 " surrounding the loop. Recall that the first entry in the list output by ",
 StyleBox[ButtonBox["Reap",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reap"], "FunctionLink"],
 " is the output of its argument. Since the argument to ",
 StyleBox[ButtonBox["Reap",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reap"], "FunctionLink"],
 " is ",
 StyleBox[ButtonBox["Do",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Do"], "FunctionLink"],
 ", which has no output, the first element of the output will be ",
 StyleBox["Null", "Input"],
 ". The second element of the output from ",
 StyleBox[ButtonBox["Reap",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reap"], "FunctionLink"],
 " is the list of lists sown by ",
 StyleBox[ButtonBox["Sow",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sow"], "FunctionLink"],
 ". So we will be able to access the list of times as the ",
 Cell["[[2,1]]", "myCode"],
 " element of the output from ",
 StyleBox[ButtonBox["Reap",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reap"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"timesExampleReap", " ", "=", 
  RowBox[{"Reap", "[", "\[IndentingNewLine]", 
   RowBox[{"Do", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Sow", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Timing", "[", 
        RowBox[{"bubbleSort", "[", 
         RowBox[{"RandomSample", "[", 
          RowBox[{"Range", "[", "20", "]"}], "]"}], "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "\[IndentingNewLine]", "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", "100", "}"}]}], "]"}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Null", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
     "0.00188499999999999995684007991769703949`3.295911267821436", ",", 
      "0.00215700000000000006311617894994014932`3.354450058382169", ",", 
      "0.00186199999999999993988142321654777334`3.2905795899249477", ",", 
      "0.00145800000000000009453549054683207942`3.1843574372615797", ",", 
      "0.00167399999999999992382482272290644687`3.244355366936865", ",", 
      "0.00161699999999999994779176226700201369`3.229309933186025", ",", 
      "0.00194499999999999989737375916121209229`3.3095195189413507", ",", 
      "0.00190200000000000004479749904362506641`3.2998104258810192", ",", 
      "0.00149000000000000000499600361081320443`3.193786181691898", ",", 
      "0.00225200000000000009545142454214783356`3.373168299458933", ",", 
      "0.00194199999999999993287314037360147267`3.30884913885161", ",", 
      "0.00203399999999999978386733268109765049`3.3289508618663497", ",", 
      "0.00200400000000000013886114480499145429`3.322497630474832", ",", 
      "0.00182599999999999993219312877101856429`3.282100686477904", ",", 
      "0.00130799999999999991794064069239311721`3.1372076572678727", ",", 
      "0.00182400000000000010041967257734540908`3.2816247472720215", ",", 
      "0.00186300000000000007260858581048523774`3.2908127681758668", ",", 
      "0.00194199999999999993287314037360147267`3.30884913885161", ",", 
      "0.00165599999999999991998067550014184235`3.2396602457284853", ",", 
      "0.00180400000000000004796163466380676255`3.2768364464855466", ",", 
      "0.00148400000000000007599476603559196519`3.1920338142226323", ",", 
      "0.00189400000000000006718237077762978515`3.2979798879468785", ",", 
      "0.00186999999999999991749655148254305459`3.292441519816123", ",", 
      "0.00162499999999999992540689053299729494`3.2314532785945174", ",", 
      "0.00227699999999999994418353743697025493`3.377962943894767", ",", 
      "0.00193500000000000008798517470154365583`3.307280882634554", ",", 
      "0.00170400000000000000251187959321441667`3.252069503710305", ",", 
      "0.0020500000000000001727784582072899866`3.3323537743353784", ",", 
      "0.00191099999999999993829935540645692527`3.3018606003346367", ",", 
      "0.00213299999999999991343035965485341876`3.3495907687290525", ",", 
      "0.00196999999999999996294630655313540046`3.315066139441217", ",", 
      "0.00215599999999999993038901635600268492`3.3542486697943255", ",", 
      "0.00163900000000000004886369087131470224`3.235178866850123", ",", 
      "0.00213500000000000017888468484272834758`3.3499977926406665", ",", 
      "0.00222000000000000018499091147816670855`3.366952887730263", ",", 
      "0.00193500000000000008798517470154365583`3.307280882634554", ",", 
      "0.00189900000000000008029688025601444679`3.2991248780166416", ",", 
      "0.00188499999999999995684007991769703949`3.295911267821436", ",", 
      "0.00201899999999999996136423874304455239`3.3257362322232633", ",", 
      "0.00165599999999999991998067550014184235`3.2396602457284853", ",", 
      "0.00150299999999999999572564135519314732`3.1975588938665322", ",", 
      "0.00174099999999999992608690213558020332`3.2613986843969553", ",", 
      "0.00194499999999999989737375916121209229`3.3095195189413507", ",", 
      "0.00156900000000000008210099267103032616`3.216222856866561", ",", 
      "0.00175599999999999996543043057073418822`3.265124424849708", ",", 
      "0.0018120000000000000255767629298020438`3.278758106620418", ",", 
      "0.00179300000000000010584588761020086167`3.274180202841807", ",", 
      "0.00183099999999999994530763824940322593`3.2832882575813205", ",", 
      "0.0020349999999999999165944952750351149`3.329164326840863", ",", 
      "0.00155600000000000009137135492665038328`3.2126095059332944", ",", 
      "0.00180600000000000009657552535458080456`3.2773176592571107", ",", 
      "0.00180100000000000008346101587619614293`3.2761136260991575", ",", 
      "0.00171799999999999990912824543443093717`3.2556230727748474", ",", 
      "0.00143800000000000004207745263329343288`3.178358799326488", ",", 
      "0.00193699999999999991975863089521681104`3.3077295339987347", ",", 
      "0.0020049999999999998379074384047271451`3.3227142902358255", ",", 
      "0.00188799999999999992134069870530765911`3.2966019032416742", ",", 
      "0.00196899999999999983021914395919793606`3.314845629417742", ",", 
      "0.00158599999999999995321797729985746628`3.2209030962612086", ",", 
      "0.00193500000000000008798517470154365583`3.307280882634554", ",", 
      "0.00183200000000000007803480084334069034`3.2835253826114554", ",", 
      "0.00189100000000000010268175199001916553`3.297291442124664", ",", 
      "0.00175800000000000001404432126150823024`3.265618784017377", ",", 
      "0.00158399999999999990460408660908342426`3.2203550905330984", ",", 
      "0.00167099999999999995932420393529582725`3.2435763631730152", ",", 
      "0.00186100000000000002399469511971119573`3.290346286410391", ",", 
      "0.0017979999999999999021199625914846365`3.275389600676834", ",", 
      "0.00176899999999999995616006831511413111`3.268327746189347", ",", 
      "0.00201100000000000020058954497415015794`3.324011983876366", ",", 
      "0.00169499999999999989216958873328167101`3.249769615818725", ",", 
      "0.0018420000000000001042638198001100136`3.2858895391404546", ",", 
      "0.00160600000000000000567601521339611281`3.2263454542222862", ",", 
      "0.00203000000000000012032042029375134007`3.3280959511928367", ",", 
      "0.0019159999999999999514138648848415869`3.3029954180221495", ",", 
      "0.00190700000000000005791200852200972804`3.3009506063256295", ",", 
      "0.00177600000000000001788846848427283476`3.2700428747222063", ",", 
      "0.00178499999999999991139032484710469362`3.272238133727836", ",", 
      "0.00196400000000000003394506897791416122`3.313741396730555", ",", 
      "0.00190900000000000010652589921278377005`3.301405841673291", ",", 
      "0.00201799999999999982863707614910708799`3.325521075180516", ",", 
      "0.00166899999999999991071031324452178524`3.2430562499588707", ",", 
      "0.00199199999999999984717780066034720221`3.3198892473673043", ",", 
      "0.00195300000000000009182932192430826035`3.311302156567478", ",", 
      "0.00205399999999999983632537059463629703`3.3332003525408833", ",", 
      "0.00203700000000000018204882046291004372`3.3295909422797885", ",", 
      "0.00180400000000000004796163466380676255`3.2768364464855466", ",", 
      "0.00169699999999999994078347942405571303`3.2502817555972996", ",", 
      "0.00160500000000000008978928711655953521`3.2260749500205153", ",", 
      "0.00163199999999999998713529070215599859`3.2333200676974663", ",", 
      "0.00194300000000000006560030296753893708`3.3090727138794067", ",", 
      "0.00230500000000000019109713811360506952`3.383270843005291", ",", 
      "0.00180199999999999999934774397303272053`3.2763546999226683", ",", 
      "0.00144500000000000010380585280245213653`3.1804677603721907", ",", 
      "0.00185500000000000009499345754448995649`3.288943827230689", ",", 
      "0.00167300000000000000793809462606986926`3.2440958542420186", ",", 
      "0.00181299999999999994146349102663862141`3.278997717375133", ",", 
      "0.00196400000000000003394506897791416122`3.313741396730555", ",", 
      "0.00150099999999999994711175066441910531`3.196980605522894", ",", 
      "0.0018120000000000000255767629298020438`3.278758106620418", ",", 
      "0.00176099999999999997854494004911884986`3.266359269246901"}], "}"}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"timesExample", "=", 
  RowBox[{"timesExampleReap", "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "1"}], "]"}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.00188499999999999995684007991769703949`3.295911267821436", ",", 
   "0.00215700000000000006311617894994014932`3.354450058382169", ",", 
   "0.00186199999999999993988142321654777334`3.2905795899249477", ",", 
   "0.00145800000000000009453549054683207942`3.1843574372615797", ",", 
   "0.00167399999999999992382482272290644687`3.244355366936865", ",", 
   "0.00161699999999999994779176226700201369`3.229309933186025", ",", 
   "0.00194499999999999989737375916121209229`3.3095195189413507", ",", 
   "0.00190200000000000004479749904362506641`3.2998104258810192", ",", 
   "0.00149000000000000000499600361081320443`3.193786181691898", ",", 
   "0.00225200000000000009545142454214783356`3.373168299458933", ",", 
   "0.00194199999999999993287314037360147267`3.30884913885161", ",", 
   "0.00203399999999999978386733268109765049`3.3289508618663497", ",", 
   "0.00200400000000000013886114480499145429`3.322497630474832", ",", 
   "0.00182599999999999993219312877101856429`3.282100686477904", ",", 
   "0.00130799999999999991794064069239311721`3.1372076572678727", ",", 
   "0.00182400000000000010041967257734540908`3.2816247472720215", ",", 
   "0.00186300000000000007260858581048523774`3.2908127681758668", ",", 
   "0.00194199999999999993287314037360147267`3.30884913885161", ",", 
   "0.00165599999999999991998067550014184235`3.2396602457284853", ",", 
   "0.00180400000000000004796163466380676255`3.2768364464855466", ",", 
   "0.00148400000000000007599476603559196519`3.1920338142226323", ",", 
   "0.00189400000000000006718237077762978515`3.2979798879468785", ",", 
   "0.00186999999999999991749655148254305459`3.292441519816123", ",", 
   "0.00162499999999999992540689053299729494`3.2314532785945174", ",", 
   "0.00227699999999999994418353743697025493`3.377962943894767", ",", 
   "0.00193500000000000008798517470154365583`3.307280882634554", ",", 
   "0.00170400000000000000251187959321441667`3.252069503710305", ",", 
   "0.0020500000000000001727784582072899866`3.3323537743353784", ",", 
   "0.00191099999999999993829935540645692527`3.3018606003346367", ",", 
   "0.00213299999999999991343035965485341876`3.3495907687290525", ",", 
   "0.00196999999999999996294630655313540046`3.315066139441217", ",", 
   "0.00215599999999999993038901635600268492`3.3542486697943255", ",", 
   "0.00163900000000000004886369087131470224`3.235178866850123", ",", 
   "0.00213500000000000017888468484272834758`3.3499977926406665", ",", 
   "0.00222000000000000018499091147816670855`3.366952887730263", ",", 
   "0.00193500000000000008798517470154365583`3.307280882634554", ",", 
   "0.00189900000000000008029688025601444679`3.2991248780166416", ",", 
   "0.00188499999999999995684007991769703949`3.295911267821436", ",", 
   "0.00201899999999999996136423874304455239`3.3257362322232633", ",", 
   "0.00165599999999999991998067550014184235`3.2396602457284853", ",", 
   "0.00150299999999999999572564135519314732`3.1975588938665322", ",", 
   "0.00174099999999999992608690213558020332`3.2613986843969553", ",", 
   "0.00194499999999999989737375916121209229`3.3095195189413507", ",", 
   "0.00156900000000000008210099267103032616`3.216222856866561", ",", 
   "0.00175599999999999996543043057073418822`3.265124424849708", ",", 
   "0.0018120000000000000255767629298020438`3.278758106620418", ",", 
   "0.00179300000000000010584588761020086167`3.274180202841807", ",", 
   "0.00183099999999999994530763824940322593`3.2832882575813205", ",", 
   "0.0020349999999999999165944952750351149`3.329164326840863", ",", 
   "0.00155600000000000009137135492665038328`3.2126095059332944", ",", 
   "0.00180600000000000009657552535458080456`3.2773176592571107", ",", 
   "0.00180100000000000008346101587619614293`3.2761136260991575", ",", 
   "0.00171799999999999990912824543443093717`3.2556230727748474", ",", 
   "0.00143800000000000004207745263329343288`3.178358799326488", ",", 
   "0.00193699999999999991975863089521681104`3.3077295339987347", ",", 
   "0.0020049999999999998379074384047271451`3.3227142902358255", ",", 
   "0.00188799999999999992134069870530765911`3.2966019032416742", ",", 
   "0.00196899999999999983021914395919793606`3.314845629417742", ",", 
   "0.00158599999999999995321797729985746628`3.2209030962612086", ",", 
   "0.00193500000000000008798517470154365583`3.307280882634554", ",", 
   "0.00183200000000000007803480084334069034`3.2835253826114554", ",", 
   "0.00189100000000000010268175199001916553`3.297291442124664", ",", 
   "0.00175800000000000001404432126150823024`3.265618784017377", ",", 
   "0.00158399999999999990460408660908342426`3.2203550905330984", ",", 
   "0.00167099999999999995932420393529582725`3.2435763631730152", ",", 
   "0.00186100000000000002399469511971119573`3.290346286410391", ",", 
   "0.0017979999999999999021199625914846365`3.275389600676834", ",", 
   "0.00176899999999999995616006831511413111`3.268327746189347", ",", 
   "0.00201100000000000020058954497415015794`3.324011983876366", ",", 
   "0.00169499999999999989216958873328167101`3.249769615818725", ",", 
   "0.0018420000000000001042638198001100136`3.2858895391404546", ",", 
   "0.00160600000000000000567601521339611281`3.2263454542222862", ",", 
   "0.00203000000000000012032042029375134007`3.3280959511928367", ",", 
   "0.0019159999999999999514138648848415869`3.3029954180221495", ",", 
   "0.00190700000000000005791200852200972804`3.3009506063256295", ",", 
   "0.00177600000000000001788846848427283476`3.2700428747222063", ",", 
   "0.00178499999999999991139032484710469362`3.272238133727836", ",", 
   "0.00196400000000000003394506897791416122`3.313741396730555", ",", 
   "0.00190900000000000010652589921278377005`3.301405841673291", ",", 
   "0.00201799999999999982863707614910708799`3.325521075180516", ",", 
   "0.00166899999999999991071031324452178524`3.2430562499588707", ",", 
   "0.00199199999999999984717780066034720221`3.3198892473673043", ",", 
   "0.00195300000000000009182932192430826035`3.311302156567478", ",", 
   "0.00205399999999999983632537059463629703`3.3332003525408833", ",", 
   "0.00203700000000000018204882046291004372`3.3295909422797885", ",", 
   "0.00180400000000000004796163466380676255`3.2768364464855466", ",", 
   "0.00169699999999999994078347942405571303`3.2502817555972996", ",", 
   "0.00160500000000000008978928711655953521`3.2260749500205153", ",", 
   "0.00163199999999999998713529070215599859`3.2333200676974663", ",", 
   "0.00194300000000000006560030296753893708`3.3090727138794067", ",", 
   "0.00230500000000000019109713811360506952`3.383270843005291", ",", 
   "0.00180199999999999999934774397303272053`3.2763546999226683", ",", 
   "0.00144500000000000010380585280245213653`3.1804677603721907", ",", 
   "0.00185500000000000009499345754448995649`3.288943827230689", ",", 
   "0.00167300000000000000793809462606986926`3.2440958542420186", ",", 
   "0.00181299999999999994146349102663862141`3.278997717375133", ",", 
   "0.00196400000000000003394506897791416122`3.313741396730555", ",", 
   "0.00150099999999999994711175066441910531`3.196980605522894", ",", 
   "0.0018120000000000000255767629298020438`3.278758106620418", ",", 
   "0.00176099999999999997854494004911884986`3.266359269246901"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["\<\
(Depending on the speed of your computer, you may need to increase the size \
of the input list in order to get non-zero times.) \
\>", "Text"],

Cell[TextData[{
 "To average the times, we apply the ",
 StyleBox[ButtonBox["Mean",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Mean"], "FunctionLink"],
 " function to the list of values."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mean", "[", "timesExample", "]"}]], "Input"],

Cell[BoxData["0.00183406000000000000233965624651943926`3.2840134524885873"], \
"Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphing the Empirically Calculated Average-case Complexity", \
"Subsection",
 CellTags->"Section3b"],

Cell[TextData[{
 "To graph the average time data, we\[CloseCurlyQuote]ll use the ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ListPlot"], "FunctionLink"],
 " function, discussed in Section 2.3 of this manual. Recall that ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ListPlot"], "FunctionLink"],
 " takes as its argument a list of lists where the sublists are ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 " pairs."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", "2"}], "}"}]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], 
    PointBox[{{1., 1.}, {2., 4.}, {3., 3.}, {4., 1.}, {5., 2.}}]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{1., 1.},
  Method->{},
  PlotRange->{{1., 5.}, {1., 4.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.08, 0.08}, {0.06, 0.06}}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We will now write a function that produces the list of data required by ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ListPlot"], "FunctionLink"],
 ". This function will compute the average, over a number of trials, of the \
time taken to execute ",
 StyleBox["bubbleSort", "Input"],
 " on randomly generated lists of size 10, 20, 30, 40, and 50."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"getBubbleTimes", "[", 
    RowBox[{
    "trials_Integer", ",", "min_Integer", ",", "max_Integer", ",", 
     "step_Integer"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"trials", ">", "0"}], "&&", 
    RowBox[{"min", ">", "0"}], "&&", 
    RowBox[{"max", ">", "min"}], "&&", 
    RowBox[{"step", ">", "0"}]}]}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"s", ",", 
      RowBox[{"avgTimeData", "=", 
       RowBox[{"{", "}"}]}], ",", "times", ",", "input"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"s", "=", "min"}], ",", 
       RowBox[{"s", "\[LessEqual]", "max"}], ",", 
       RowBox[{"s", "=", 
        RowBox[{"s", "+", "step"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"times", "=", 
         RowBox[{
          RowBox[{"Reap", "[", "\[IndentingNewLine]", 
           RowBox[{"Do", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"input", "=", 
               RowBox[{"RandomSample", "[", 
                RowBox[{"Range", "[", "s", "]"}], "]"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"Sow", "[", 
               RowBox[{
                RowBox[{"Timing", "[", 
                 RowBox[{"bubbleSort", "[", "input", "]"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", "trials", "}"}]}], "]"}], "\[IndentingNewLine]", 
           "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"avgTimeData", ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", 
            RowBox[{"Mean", "[", "times", "]"}]}], "}"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "avgTimeData"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True],

Cell[TextData[{
 "Most of the function is enclosed in the ",
 StyleBox[ButtonBox["For",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/For"], "FunctionLink"],
 " loop with variable ",
 StyleBox["s", "Input"],
 ", representing the size of the input that will be passed to ",
 StyleBox["bubbleSort", "Input"],
 ". Within the ",
 StyleBox[ButtonBox["For",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/For"], "FunctionLink"],
 " loop are two statements: the first is an assignment to the symbol ",
 StyleBox["times", "Input"],
 ", the right hand side of which spans 6 lines of code, and the second \
appends the average of the data stored in ",
 StyleBox["times", "Input"],
 " to the symbol ",
 StyleBox["avgTimeData", "Input"],
 ". The right hand side of the ",
 StyleBox["times", "Input"],
 " assignment is where most of the work is done. A ",
 StyleBox[ButtonBox["Reap",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reap"], "FunctionLink"],
 " encloses this section of code, and ",
 StyleBox["times", "Input"],
 " is assigned to the ",
 StyleBox["[[2,1]]", "Input"],
 " entry of the output of the ",
 StyleBox[ButtonBox["Reap",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reap"], "FunctionLink"],
 ", which effectively assigns times to the sown values. Within the ",
 StyleBox[ButtonBox["Reap",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reap"], "FunctionLink"],
 " is a ",
 StyleBox[ButtonBox["Do",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Do"], "FunctionLink"],
 " loop, the second argument of which, ",
 StyleBox["{trials}", "Input"],
 ", indicates that the body of the ",
 StyleBox[ButtonBox["Do",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Do"], "FunctionLink"],
 " loop will be executed a number of times dictated by the argument to the \
function. There is no need for a loop variable. Within the ",
 StyleBox[ButtonBox["Do",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Do"], "FunctionLink"],
 " loop, the symbol ",
 StyleBox["input", "Input"],
 " is assigned to the result of ",
 StyleBox[ButtonBox["RandomSample",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RandomSample"], "FunctionLink"],
 " applied to the list of positive integers determined by the input size ",
 StyleBox["s", "Input"],
 ". Then ",
 StyleBox["bubbleSort", "Input"],
 " is applied to this input within ",
 StyleBox[ButtonBox["Timing",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Timing"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["Sow",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sow"], "FunctionLink"],
 " is applied to the time. Note that, unlike our example above, we moved the \
application of ",
 StyleBox[ButtonBox["RandomSample",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RandomSample"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["Range",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Range"], "FunctionLink"],
 " outside of the ",
 StyleBox[ButtonBox["Timing",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Timing"], "FunctionLink"],
 " function, so that the time taken to generate the random input is not being \
included."
}], "Text"],

Cell["\<\
Now we execute the function and use the result to create a graph.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bubbleTimes", "=", 
  RowBox[{"getBubbleTimes", "[", 
   RowBox[{"100", ",", "10", ",", "50", ",", "10"}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "10", ",", "0.00052148000000000000126246235687688113`2.737837570133835"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "20", ",", 
     "0.00184888000000000000695027368990963623`3.2875086378357445"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
    "30", ",", 
     "0.00417933999999999996905614141340379319`3.6417076168275133"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
    "40", ",", 
     "0.00742180000000000003775035839481688527`3.8911091602384005"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
    "50", ",", "0.01147031999999999999501065772733454651`4.080175447335698"}],
     "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "bubbleTimes", "]"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.24720000000000014`, 0.24, 0.6], 
    PointBox[{{10., 0.00052148}, {20., 0.00184888}, {30., 0.00417934}, {40., 
     0.0074218}, {50., 0.011470319999999999`}}]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{10., 0},
  Method->{},
  PlotRange->{{10., 50.}, {0, 0.011470319999999999`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.8, 0.8}, {0.00022940639999999998`, 
   0.00022940639999999998`}}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "From the shape of the graph, it appears that the average-case performance \
of ",
 StyleBox["bubbleSort", "Input"],
 " is polynomial. This suggests that the complexity of the algorithm is also \
polynomial. Of course, a proof of that fact would require an analysis of the \
kind given in Example 4 of Section 3.3. "
}], "Text"],

Cell["\<\
The reader can experiment with the function in order to produce finer detail \
(by decreasing the step) and to obtain data for larger input lists (by \
increasing the maximum list size). \
\>", "Text"],

Cell["\<\
We conclude with a caveat. The empirical testing we've done in this section \
is an example of a way to get an idea of the average-case performance of a \
procedure. It can be used to compare two or more algorithms with each other \
and can indicate major differences in worst-case and average-case complexity \
(for instance, in an algorithm with exponential worst-case complexity and \
polynomial average-case complexity). But beyond generalities, the \
implementation of the algorithm, the computer running it, the computer \
language it is written in, and a host of other factors can play a \
sufficiently significant role that this approach is generally not helpful for \
making finer distinctions (between quadratic and cubic complexity, for \
example).\
\>", "Text"],

Cell["\<\
The reader should refer to the solution of Computer Project 9 below for a \
method of analyzing average case complexity that modifies the function in \
order to count the number of operations used with the input values. \
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Solutions to Computer Projects and Computations and Explorations\
\>", "Section",
 CellTags->"Solutions"],

Cell[CellGroupData[{

Cell["Computer Project 9", "Subsection",
 CellTags->"SolutionsCP9"],

Cell[TextData[{
 "Given an ordered list of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " integers and an integer ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " in the list, find the number of comparisons used to determine the position \
of ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " in the list using a linear search and using a binary search. "
}], "Problem"],

Cell[TextData[{
 StyleBox["Solution:",
  FontSlant->"Italic"],
 " There is no loss of generality to assume that the list of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " integers is the list of integers from ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "For the linear search algorithm provided as Algorithm 2 in Section 3.1 of \
the text, each step in the search requires 2 comparisons, one tests whether \
the end of the list has been reached and one tests whether the current \
element is the element being searched for. These are both contained in the \
Boolean expression that controls the while loop. A final comparison is used \
after the while loop is completed to determine whether the element was found \
or not. In the list of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " integers ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]]],
 " through ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 ", the integer ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " is therefore found after ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"2", "x"}], "+", "1"}], TraditionalForm]]],
 " comparisons. "
}], "Text"],

Cell[TextData[{
 "To determine the number of comparisons needed to find ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " via the binary search algorithm, we'll modify the procedure we wrote in \
Section 3.1 of this manual to count comparisons. For reference, here is the \
original ",
 StyleBox["binarySearch", "Input"],
 " function. "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"binarySearch", "[", 
   RowBox[{"x_Integer", ",", 
    RowBox[{"A", ":", 
     RowBox[{"{", "__Integer", "}"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", ",", "i", ",", "j", ",", "m", ",", "location"}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", "A", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"i", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"j", "=", "n"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"i", "<", "j"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"m", "=", 
         RowBox[{"Floor", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"i", "+", "j"}], ")"}], "/", "2"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"x", ">", 
           RowBox[{"A", "[", 
            RowBox[{"[", "m", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"i", "=", 
           RowBox[{"m", "+", "1"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"j", "=", "m"}]}], "\[IndentingNewLine]", "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"x", "\[Equal]", 
        RowBox[{"A", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"location", "=", "i"}], ",", "\[IndentingNewLine]", 
       RowBox[{"location", "=", "0"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", "location"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "myCode"],

Cell[TextData[{
 "We will modify this function to count comparisons. Each time through the ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop accounts for 2 comparisons, the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"i", "<", "j"}], TraditionalForm]]],
 " comparison that controls the loop and the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", ">", 
    RowBox[{"A", "[", "m", "]"}]}], TraditionalForm]]],
 " comparison in the ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statement. So we'll add a line of code to increment the comparison count \
by 2 at the start of the ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop. Also, we need to add one to the comparison count after the end of \
the loop to account for the comparison that terminates the loop. And one \
final comparison is done, in the final ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statement, to determine if the search has succeeded or not. "
}], "Text"],

Cell[TextData[{
 "By incrementing the count after the final ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statement, the increment will be the final expression and consequently is \
what will be shown as the result of the function. Here is the modified \
function. "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"binarySearchC", "[", 
   RowBox[{"x_Integer", ",", 
    RowBox[{"A", ":", 
     RowBox[{"{", "__Integer", "}"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", ",", "i", ",", "j", ",", "m", ",", "location", ",", 
      RowBox[{"count", "=", "0"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", "A", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"i", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"j", "=", "n"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"i", "<", "j"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"count", "=", 
         RowBox[{"count", "+", "2"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"m", "=", 
         RowBox[{"Floor", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"i", "+", "j"}], ")"}], "/", "2"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"x", ">", 
           RowBox[{"A", "[", 
            RowBox[{"[", "m", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"i", "=", 
           RowBox[{"m", "+", "1"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"j", "=", "m"}]}], "\[IndentingNewLine]", "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"count", "=", 
      RowBox[{"count", "+", "1"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"x", "\[Equal]", 
        RowBox[{"A", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"location", "=", "i"}], ",", "\[IndentingNewLine]", 
       RowBox[{"location", "=", "0"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"count", "=", 
      RowBox[{"count", "+", "1"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell["For example, to find 15 in the list from 1 to 20, it takes", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"binarySearchC", "[", 
  RowBox[{"15", ",", 
   RowBox[{"Range", "[", "20", "]"}]}], "]"}]], "Input"],

Cell[BoxData["10"], "Output"]
}, Open  ]],

Cell["comparisons.", "Text"],

Cell[TextData[{
 "We can use the information above to compare the average number of \
comparisons required in a list of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " elements. We need to determine the number of comparisons needed to find \
each value from ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " in the list from ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " and average these numbers of comparisons. For the linear search, we know \
that it takes ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"2", "x"}], "+", "1"}], TraditionalForm]]],
 " comparisons, so the average can be found from "
}], "Text"],

Cell[BoxData[
 FormBox[Cell[TextData[Cell[BoxData[
   FormBox[
    FractionBox[
     RowBox[{
      RowBox[{
       UnderoverscriptBox[
        StyleBox["\[Sum]",
         FontSize->14], 
        RowBox[{"x", "=", "1"}], "n",
        LimitsPositioning->False], " ", 
       RowBox[{"2", "x"}]}], "+", "1"}], "n"], TraditionalForm]]]]], 
  TraditionalForm]], "Equation"],

Cell[TextData[{
 "We use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s symbolic summation capabilities, specifically the ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " function (discussed in Section 2.4 of this manual)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"2", "*", "x"}], "+", "1"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "1", ",", "n"}], "}"}]}], "]"}], "/", "n"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"2", " ", "n"}], "+", 
   SuperscriptBox["n", "2"]}], "n"]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"2", "+", "n"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "(The ",
 StyleBox[ButtonBox["Simplify",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Simplify"], "FunctionLink"],
 " function forces ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to simplify expressions.)"
}], "Text"],

Cell[TextData[{
 "For the binary search function, we can find the average by applying our \
function above to each integer in turn and taking the average. The following \
function will produce the average number of comparisons required for a given \
value of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"binaryAvg", "[", "n_Integer", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"data", "=", 
       RowBox[{"{", "}"}]}], ",", "inputList", ",", "x"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"inputList", "=", 
      RowBox[{"Range", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"data", "=", 
      RowBox[{
       RowBox[{"Reap", "[", "\[IndentingNewLine]", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"Sow", "[", 
           RowBox[{"binarySearchC", "[", 
            RowBox[{"x", ",", "inputList"}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"x", ",", "1", ",", "n"}], "}"}]}], "\[IndentingNewLine]", 
         "]"}], "\[IndentingNewLine]", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Mean", "[", "data", "]"}], "//", "N"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True],

Cell[TextData[{
 "The function ",
 StyleBox[ButtonBox["N",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/N"], "FunctionLink"],
 " is used to obtain an numerical (floating point) value of an exact \
expression. Without it, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " would return a fraction as the result of this function, but we generally \
expect means to be reported as floating point numbers."
}], "Text"],

Cell[TextData[{
 "For example, in the list from 1 to 20, it requires an average of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"20", "+", "2"}], "=", "22"}], TraditionalForm]]],
 " comparisons using the linear search, and an average of 10.8 comparisons \
using the binary search."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"binaryAvg", "[", "20", "]"}]], "Input"],

Cell[BoxData["10.8`"], "Output"]
}, Open  ]],

Cell[TextData[{
 "Next, we'll graph the average number of comparisons as ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " ranges from ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox["100", TraditionalForm]]],
 ". "
}], "Text"],

Cell[TextData[{
 "For the linear search algorithm, we will graph the function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "+", "2"}], TraditionalForm]]],
 " using ",
 StyleBox[ButtonBox["Plot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Plot"], "FunctionLink"],
 ". In Section 2.5 of this manual, we demonstrated how to overlay two graphs \
using the ",
 StyleBox[ButtonBox["Show",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Show"], "FunctionLink"],
 " function. We will use the same approach here. Keep in mind when doing this \
that since the two graphs are created separately, the functions will have the \
same color if you do not specify the color manually using the ",
 StyleBox[ButtonBox["PlotStyle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlotStyle"], "FunctionLink"],
 " option."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"linearSearchGraph", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"n", "+", "2"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1", ",", "100"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJw10H9Q02UAx/GFZ2x4hcBCQzSmFxmHO3coQgLfT+CPYPJjwNzzJKRwcBYq
IHKwBaZ150xBSy/8QZ2mmCnnERCoKfFrAXay1Jtx1qlsFuwEpA3KsbQW+X2e
P973+v+tyC1Kz/eSSCTJ0/2vOo8u8JI4hNDmcN/nJFJ8cHpP4KZKhyDcip+1
NE6KZmvTi+1TDoE6iPfGSinmZvt4DE6nUK3c42mbkmJYe3XQ+WBSmKy/94fe
KcNHa+efsvW4hK66gzcdD2bhSphtUVeVR8iucRyy9vjiM32LvLPKG0kxb/tY
ewIQdH3gtZAIOTMYCVXVqi1+wTi9uvdYq3QhutMXG1/+XcF8Fd+0DncuCQhl
hiGxqWt739+vM5eg0ctd5BepBPnw6SXpPBUOdW4Y7VdyIxCy7sdfLAu4y3HE
a2i8OYq7ArkzfTtuK7nRaDlRaXppHnclxnKPjStV3FhU7Oi+vX8RV4CjodbW
LgjQ68zFgyeBMmzwk53nvomTqcW+mV9y47Gy9G5I1QVuArw6bnzy21nuKsS+
EuS/+CJ3Na4mGZWVndw1yPvCcM55mbsWu2f8sDyjl/sW+j6tCRno4iZC8/Dj
r969zE1Cis4Sazdx1SgbPROx93vuOvjXmGMC+rnJcMrmWht+5qbgyZmH1i1m
bir0Wv+/5L+moi1s3/s+29IwOzDn26IC5kgaZtoTv8saYuZr0BJ//1pHAXNE
A70qcm+Enbk5HY/ro1PnFzLH07HvkqR3zhhzawbaz9+R1W5m2jNwITRLd/gR
c1smGiPrMj4vYI5kovBWDQ2aYJZoYdYcD1eUM11axOdvaoiaZO5Yj+IZluhe
A9O9Hi3LZKV5Lma5DsfVaRX7S5gTOkQ9iq8OnWLqCcYUbrWllPknwU+6r//1
lDEfEzQe0DaFG5huglJ3U6BxJ/Mfgqc3C2xRRubzFC/svlt24igRnUOhvN9x
6r0rRPQNitnywswjbUQ0hmIiMdjb1E5E4ygutuq3BpuIaAJF3AHVihvXiaia
IiWmrn/ZPSKaTbG0RLMrZ5CIbqTwP+dRHbQR0RyKgYCso/YhIppP8c6oPLd2
nIgWUkBhkvc5iGgxxULd9r7JCSJaQjHcbQ5PdhHRcoprUxWDhukPzzRQ1CvD
Dp99QkQrKKrz7qyyTH955k6Kolqjy+Mhorso/gP1lzGG
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{1, 100}, {0., 101.99999797959184`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output"]
}, Open  ]],

Cell["", "Text"],

Cell[TextData[{
 "For the binary search algorithm, we must first create the necessary data \
before we can graph it with the ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ListPlot"], "FunctionLink"],
 " function. Recall from Section 3.2 of this manual that ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ListPlot"], "FunctionLink"],
 " requires a list of the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 " pairs given as sublists. The ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " values will be the values of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"binarySearchdata", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"binaryAvg", "[", "n", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "100"}], "}"}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"binarySearchGraph", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"binarySearchdata", ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJxdk1lIVHEYxYckCHtIyaIyM80ll8bKPXP8XMfdmXHGGYuUorCHRKIXM7Ap
o8VIKcwoTFsMsU3azNzSyMigshJ7MFKTcOnBICJHDZrRc4T8+A/f/O65h/u/
3/9ctz0Fun2LFArFXuvP1ufqZxT+yP/dAX2JGGZrxYLrq9CdJHC2nOevz93v
Al4rT/P7G/P714HXL+juEl42HFY2TPaQK5dt5Qb2koDm0Rtnle7gjXLntq3I
vhLxYLl1bQD7i+1pjflkpbS22Iq8ef45c32LFM4WeSv2Qw6UkIrPmpxYT3AQ
9kcOlqLqkcPVI+QQ7NcLHCp1oW1jaQXkMOyfHC5DRU731UPkbXgfb3CEeD2+
1JMTQ96O9yNHyprdz+ocK8kqvC85SgaOTLT9+UqW+TnONrOIanKwZJkKrIjG
PKhHi6W0YbK0gXoM5kM9RlLPv2/udPKBHot5gc2xYqkssC7qcZgf9Th5YVlV
Vd5JPR7zpB4vJe3XAkaX+kJPwHzB5gSZqs2wLupqzJu6WsYjnH9fPUc9EfOn
nigPVUF9p15RT8J5UE+S6SlbUU/G+fhBT5Yet+DOQj+wIgXnRT1FTNMnnxSY
qKfi/KinikdT+aDqOPU0nCf1NIlsdN8fVk89HedLPV0OdjvcvfmWegbOm3qG
zLRPTLdPUNeg+8910cjkMVfrAps1yAO4QyNeH+0uPtoJVmiRD/q1cqZG+y2v
gn4t8kK/ViJXP9813k2/DvmhXyevy12jimfo1yFPm+DXib+l60KuP1iRiXyB
JVMc8757v8wGmzORN/ozxf5Xy44vJ+jXI3/06+V0/JuOT/fo1yOP9OtlpZ1n
64de+g3IJ/0GmbLYin4D8qqE3yDv+q4PHHABK7KQX7BkSa3r31F1FNichTzT
b+VbudZFvxH5pt8oR6fG6mqK6Tci7/Qbpat+4FBKFf0m5J9+k0xHqxe3N9Fv
wvdAv0l8ND+M9r30Z+P7UMo/qzuvqQ==
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 100.}, {0, 15.44}},
  PlotRangeClipping->True,
  PlotRangePadding->{{2., 2.}, {0.3088, 0.3088}}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We overlay the two graphs using ",
 StyleBox[ButtonBox["Show",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Show"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"linearSearchGraph", ",", "binarySearchGraph"}], "]"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJw10H9Q02UAx/GFZ2x4hcBCQzSmFxmHO3coQgLfT+CPYPJjwNzzJKRwcBYq
IHKwBaZ150xBSy/8QZ2mmCnnERCoKfFrAXay1Jtx1qlsFuwEpA3KsbQW+X2e
P973+v+tyC1Kz/eSSCTJ0/2vOo8u8JI4hNDmcN/nJFJ8cHpP4KZKhyDcip+1
NE6KZmvTi+1TDoE6iPfGSinmZvt4DE6nUK3c42mbkmJYe3XQ+WBSmKy/94fe
KcNHa+efsvW4hK66gzcdD2bhSphtUVeVR8iucRyy9vjiM32LvLPKG0kxb/tY
ewIQdH3gtZAIOTMYCVXVqi1+wTi9uvdYq3QhutMXG1/+XcF8Fd+0DncuCQhl
hiGxqWt739+vM5eg0ctd5BepBPnw6SXpPBUOdW4Y7VdyIxCy7sdfLAu4y3HE
a2i8OYq7ArkzfTtuK7nRaDlRaXppHnclxnKPjStV3FhU7Oi+vX8RV4CjodbW
LgjQ68zFgyeBMmzwk53nvomTqcW+mV9y47Gy9G5I1QVuArw6bnzy21nuKsS+
EuS/+CJ3Na4mGZWVndw1yPvCcM55mbsWu2f8sDyjl/sW+j6tCRno4iZC8/Dj
r969zE1Cis4Sazdx1SgbPROx93vuOvjXmGMC+rnJcMrmWht+5qbgyZmH1i1m
bir0Wv+/5L+moi1s3/s+29IwOzDn26IC5kgaZtoTv8saYuZr0BJ//1pHAXNE
A70qcm+Enbk5HY/ro1PnFzLH07HvkqR3zhhzawbaz9+R1W5m2jNwITRLd/gR
c1smGiPrMj4vYI5kovBWDQ2aYJZoYdYcD1eUM11axOdvaoiaZO5Yj+IZluhe
A9O9Hi3LZKV5Lma5DsfVaRX7S5gTOkQ9iq8OnWLqCcYUbrWllPknwU+6r//1
lDEfEzQe0DaFG5huglJ3U6BxJ/Mfgqc3C2xRRubzFC/svlt24igRnUOhvN9x
6r0rRPQNitnywswjbUQ0hmIiMdjb1E5E4ygutuq3BpuIaAJF3AHVihvXiaia
IiWmrn/ZPSKaTbG0RLMrZ5CIbqTwP+dRHbQR0RyKgYCso/YhIppP8c6oPLd2
nIgWUkBhkvc5iGgxxULd9r7JCSJaQjHcbQ5PdhHRcoprUxWDhukPzzRQ1CvD
Dp99QkQrKKrz7qyyTH955k6Kolqjy+Mhorso/gP1lzGG
      "]]}}, {{}, 
    {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJxdk1lIVHEYxYckCHtIyaIyM80ll8bKPXP8XMfdmXHGGYuUorCHRKIXM7Ap
o8VIKcwoTFsMsU3azNzSyMigshJ7MFKTcOnBICJHDZrRc4T8+A/f/O65h/u/
3/9ctz0Fun2LFArFXuvP1ufqZxT+yP/dAX2JGGZrxYLrq9CdJHC2nOevz93v
Al4rT/P7G/P714HXL+juEl42HFY2TPaQK5dt5Qb2koDm0Rtnle7gjXLntq3I
vhLxYLl1bQD7i+1pjflkpbS22Iq8ef45c32LFM4WeSv2Qw6UkIrPmpxYT3AQ
9kcOlqLqkcPVI+QQ7NcLHCp1oW1jaQXkMOyfHC5DRU731UPkbXgfb3CEeD2+
1JMTQ96O9yNHyprdz+ocK8kqvC85SgaOTLT9+UqW+TnONrOIanKwZJkKrIjG
PKhHi6W0YbK0gXoM5kM9RlLPv2/udPKBHot5gc2xYqkssC7qcZgf9Th5YVlV
Vd5JPR7zpB4vJe3XAkaX+kJPwHzB5gSZqs2wLupqzJu6WsYjnH9fPUc9EfOn
nigPVUF9p15RT8J5UE+S6SlbUU/G+fhBT5Yet+DOQj+wIgXnRT1FTNMnnxSY
qKfi/KinikdT+aDqOPU0nCf1NIlsdN8fVk89HedLPV0OdjvcvfmWegbOm3qG
zLRPTLdPUNeg+8910cjkMVfrAps1yAO4QyNeH+0uPtoJVmiRD/q1cqZG+y2v
gn4t8kK/ViJXP9813k2/DvmhXyevy12jimfo1yFPm+DXib+l60KuP1iRiXyB
JVMc8757v8wGmzORN/ozxf5Xy44vJ+jXI3/06+V0/JuOT/fo1yOP9OtlpZ1n
64de+g3IJ/0GmbLYin4D8qqE3yDv+q4PHHABK7KQX7BkSa3r31F1FNichTzT
b+VbudZFvxH5pt8oR6fG6mqK6Tci7/Qbpat+4FBKFf0m5J9+k0xHqxe3N9Fv
wvdAv0l8ND+M9r30Z+P7UMo/qzuvqQ==
      "]]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{1, 100}, {0., 101.99999797959184`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Below we display the same graph using ",
 StyleBox[ButtonBox["Legended",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Legended"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["LineLegend",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/LineLegend"], "FunctionLink"],
 " to illustrate some of the additional legending options."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Legended", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"linearSearchGraph", ",", "binarySearchGraph"}], "]"}], ",", 
   RowBox[{"LineLegend", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Red", ",", "Blue"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<linear\>\"", ",", "\"\<binary\>\""}], "}"}], ",", 
     RowBox[{"LegendFunction", "\[Rule]", "Framed"}]}], "]"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       RGBColor[1, 0, 0], 
       LineBox[CompressedData["
1:eJw10H9Q02UAx/GFZ2x4hcBCQzSmFxmHO3coQgLfT+CPYPJjwNzzJKRwcBYq
IHKwBaZ150xBSy/8QZ2mmCnnERCoKfFrAXay1Jtx1qlsFuwEpA3KsbQW+X2e
P973+v+tyC1Kz/eSSCTJ0/2vOo8u8JI4hNDmcN/nJFJ8cHpP4KZKhyDcip+1
NE6KZmvTi+1TDoE6iPfGSinmZvt4DE6nUK3c42mbkmJYe3XQ+WBSmKy/94fe
KcNHa+efsvW4hK66gzcdD2bhSphtUVeVR8iucRyy9vjiM32LvLPKG0kxb/tY
ewIQdH3gtZAIOTMYCVXVqi1+wTi9uvdYq3QhutMXG1/+XcF8Fd+0DncuCQhl
hiGxqWt739+vM5eg0ctd5BepBPnw6SXpPBUOdW4Y7VdyIxCy7sdfLAu4y3HE
a2i8OYq7ArkzfTtuK7nRaDlRaXppHnclxnKPjStV3FhU7Oi+vX8RV4CjodbW
LgjQ68zFgyeBMmzwk53nvomTqcW+mV9y47Gy9G5I1QVuArw6bnzy21nuKsS+
EuS/+CJ3Na4mGZWVndw1yPvCcM55mbsWu2f8sDyjl/sW+j6tCRno4iZC8/Dj
r969zE1Cis4Sazdx1SgbPROx93vuOvjXmGMC+rnJcMrmWht+5qbgyZmH1i1m
bir0Wv+/5L+moi1s3/s+29IwOzDn26IC5kgaZtoTv8saYuZr0BJ//1pHAXNE
A70qcm+Enbk5HY/ro1PnFzLH07HvkqR3zhhzawbaz9+R1W5m2jNwITRLd/gR
c1smGiPrMj4vYI5kovBWDQ2aYJZoYdYcD1eUM11axOdvaoiaZO5Yj+IZluhe
A9O9Hi3LZKV5Lma5DsfVaRX7S5gTOkQ9iq8OnWLqCcYUbrWllPknwU+6r//1
lDEfEzQe0DaFG5huglJ3U6BxJ/Mfgqc3C2xRRubzFC/svlt24igRnUOhvN9x
6r0rRPQNitnywswjbUQ0hmIiMdjb1E5E4ygutuq3BpuIaAJF3AHVihvXiaia
IiWmrn/ZPSKaTbG0RLMrZ5CIbqTwP+dRHbQR0RyKgYCso/YhIppP8c6oPLd2
nIgWUkBhkvc5iGgxxULd9r7JCSJaQjHcbQ5PdhHRcoprUxWDhukPzzRQ1CvD
Dp99QkQrKKrz7qyyTH955k6Kolqjy+Mhorso/gP1lzGG
        "]]}}, {{}, {
       RGBColor[0, 0, 1], 
       PointBox[CompressedData["
1:eJxdk1lIVHEYxYckCHtIyaIyM80ll8bKPXP8XMfdmXHGGYuUorCHRKIXM7Ap
o8VIKcwoTFsMsU3azNzSyMigshJ7MFKTcOnBICJHDZrRc4T8+A/f/O65h/u/
3/9ctz0Fun2LFArFXuvP1ufqZxT+yP/dAX2JGGZrxYLrq9CdJHC2nOevz93v
Al4rT/P7G/P714HXL+juEl42HFY2TPaQK5dt5Qb2koDm0Rtnle7gjXLntq3I
vhLxYLl1bQD7i+1pjflkpbS22Iq8ef45c32LFM4WeSv2Qw6UkIrPmpxYT3AQ
9kcOlqLqkcPVI+QQ7NcLHCp1oW1jaQXkMOyfHC5DRU731UPkbXgfb3CEeD2+
1JMTQ96O9yNHyprdz+ocK8kqvC85SgaOTLT9+UqW+TnONrOIanKwZJkKrIjG
PKhHi6W0YbK0gXoM5kM9RlLPv2/udPKBHot5gc2xYqkssC7qcZgf9Th5YVlV
Vd5JPR7zpB4vJe3XAkaX+kJPwHzB5gSZqs2wLupqzJu6WsYjnH9fPUc9EfOn
nigPVUF9p15RT8J5UE+S6SlbUU/G+fhBT5Yet+DOQj+wIgXnRT1FTNMnnxSY
qKfi/KinikdT+aDqOPU0nCf1NIlsdN8fVk89HedLPV0OdjvcvfmWegbOm3qG
zLRPTLdPUNeg+8910cjkMVfrAps1yAO4QyNeH+0uPtoJVmiRD/q1cqZG+y2v
gn4t8kK/ViJXP9813k2/DvmhXyevy12jimfo1yFPm+DXib+l60KuP1iRiXyB
JVMc8757v8wGmzORN/ozxf5Xy44vJ+jXI3/06+V0/JuOT/fo1yOP9OtlpZ1n
64de+g3IJ/0GmbLYin4D8qqE3yDv+q4PHHABK7KQX7BkSa3r31F1FNichTzT
b+VbudZFvxH5pt8oR6fG6mqK6Tci7/Qbpat+4FBKFf0m5J9+k0xHqxe3N9Fv
wvdAv0l8ND+M9r30Z+P7UMo/qzuvqQ==
        "]]}, {}}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
    PlotRange -> {{1, 100}, {0., 101.99999797959184`}}, PlotRangeClipping -> 
    True, PlotRangePadding -> {
      Scaled[0.02], 
      Scaled[0.02]}],
   TemplateBox[{"\"linear\"", "\"binary\""}, "LineLegend", 
    DisplayFunction -> (FrameBox[
      StyleBox[
       StyleBox[
        PaneBox[
         TagBox[
          GridBox[{{
             TagBox[
              GridBox[{{
                 GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                  ImageSize -> {20, 10}, PlotRangePadding -> None, 
                  ImagePadding -> 1, 
                  BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                 GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                  ImageSize -> {20, 10}, PlotRangePadding -> None, 
                  ImagePadding -> 1, 
                  BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
               GridBoxAlignment -> {
                "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
               AutoDelete -> False, 
               GridBoxDividers -> {
                "Columns" -> {{False}}, "Rows" -> {{False}}}, 
               GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
              "Grid"]}}, 
           GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
           AutoDelete -> False, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
           GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"],
          Alignment -> Left, AppearanceElements -> None, 
         ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
        LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
       Background -> Automatic, StripOnInput -> False], StripOnInput -> 
      False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"RGBColor", "[", 
               RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
             RowBox[{"RGBColor", "[", 
               RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendFunction", "\[Rule]", "Framed"}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Computations and Explorations 1", "Subsection",
 PageBreakWithin->False,
 CellTags->"SolutionsCE1"],

Cell[TextData[{
 "We know that ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["n", "b"], TraditionalForm]]],
 " is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SuperscriptBox["d", "n"], ")"}], TraditionalForm]]],
 " when ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]]],
 " are positive numbers with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"d", "\[GreaterEqual]", "2"}], TraditionalForm]]],
 ". Give values of the constants ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 " such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["n", "b"], "\[LessEqual]", 
    RowBox[{"C", "\[CenterDot]", 
     SuperscriptBox["d", "n"]}]}], TraditionalForm]]],
 " whenever ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", ">", "k"}], TraditionalForm]]],
 " for each of these sets of values: ",
 Cell[BoxData[
  FormBox[
   RowBox[{"b", "=", "10"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"d", "=", "2"}], TraditionalForm]]],
 "; ",
 Cell[BoxData[
  FormBox[
   RowBox[{"b", "=", "20"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"d", "=", "3"}], TraditionalForm]]],
 "; ",
 Cell[BoxData[
  FormBox[
   RowBox[{"b", "=", "1000"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"d", "=", "7"}], TraditionalForm]]],
 "."
}], "Problem",
 PageBreakAbove->False,
 PageBreakWithin->False],

Cell[TextData[{
 StyleBox["Solution:",
  FontSlant->"Italic"],
 " For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"b", "=", "10"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"d", "=", "2"}], TraditionalForm]]],
 ", we need to compare the function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "n", ")"}], "=", 
    SuperscriptBox["n", "10"]}], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"g", "(", "n", ")"}], "=", 
    SuperscriptBox["2", "n"]}], TraditionalForm]]],
 ". Following the approach we took in Section 3.2, we will use ",
 StyleBox[ButtonBox["Manipulate",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Manipulate"], "FunctionLink"],
 " to graph the functions while dynamically changing the value of ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]]],
 ". Note that the values of ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]]],
 " that will suffice with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "<", "20"}], TraditionalForm]]],
 " are extremely large. When exploring other values of ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]]],
 ", you may have to modify the maximum values for ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]]],
 ". It is also possible to find smaller values of ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]]],
 " by increasing the horizontal extent of the graph."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"n", "^", "10"}], ",", 
       RowBox[{"c", "*", 
        RowBox[{"2", "^", "n"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "20"}], "}"}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", "\"\<Expressions\>\""}]}], "]"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"c", ",", "0", ",", 
     RowBox[{"10", "^", "8"}]}], "}"}]}], "]"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`c$$], 0, 100000000}}, Typeset`size$$ = {
    434., {102., 107.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`c$150379$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`c$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$150379$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Plot[{$CellContext`n^10, $CellContext`c$$ 
         2^$CellContext`n}, {$CellContext`n, 0, 20}, PlotLegends -> 
        "Expressions"], 
      "Specifications" :> {{$CellContext`c$$, 0, 100000000}}, "Options" :> {},
       "DefaultOptions" :> {}],
     ImageSizeCache->{477., {145., 150.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "Section",
 CellTags->"Exercises"],

Cell[CellGroupData[{

Cell[TextData[{
 "Write step-by-step instructions, then pseudocode, and then implement in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " an algorithm to determine the ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 " largest integers in a list of integers."
}], "Item1Exercise"],

Cell["\<\
Implement the linear search presented as Algorithm 2 in Section 3.1 of the \
text. \
\>", "Item1Exercise"],

Cell["\<\
Implement the insertion sort presented as Algorithm 5 in Section 3.1 of the \
text. \
\>", "Item1Exercise"],

Cell["\<\
Implement the greedy change-making algorithm presented as Algorithm 6 in \
Section 3.1 of the text. \
\>", "Item1Exercise"],

Cell["\<\
Implement the algorithm for scheduling talks presented as Algorithm 7 in \
Section 3.1 of the text. \
\>", "Item1Exercise"],

Cell["\<\
Implement the brute-force algorithm for finding the closest pair of points as \
presented in Algorithm 3 in Section 3.3 of the text. \
\>", "Item1Exercise"],

Cell[TextData[{
 "Modify the ",
 StyleBox["bubbleSort", "Input"],
 " function so that it terminates when no more interchanges are necessary. \
(See Exercise 37 from Section 3.1.)"
}], "Item1Exercise"],

Cell[TextData[{
 "Implement the selection sort algorithm in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". (Refer to the preamble to Exercise 41 in Section 3.1 for information on \
selection sort.) "
}], "Item1Exercise"],

Cell[TextData[{
 "Implement the binary insertion sort in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". (Refer to the preamble to Exercise 47 in Section 3.1 for information on \
the binary insertion sort.)"
}], "Item1Exercise"],

Cell[TextData[{
 "Implement the deferred acceptance algorithm in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". (Refer to the preamble to Exercise 61 in Section 3.1 for information on \
the deferred acceptance algorithm.)"
}], "Item1Exercise"],

Cell[TextData[{
 "Following the solution to Computations and Explorations 1, use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to determine values for ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 " that witness for the fact that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "x", ")"}], TraditionalForm]]],
 " is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    RowBox[{"g", "(", "x", ")"}], ")"}], TraditionalForm]]],
 " for each of the pairs of functions given below."
}], "Item1Exercise"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    RowBox[{"7", "\[CenterDot]", 
     RowBox[{"ln", "(", 
      RowBox[{
       RowBox[{"3", 
        SuperscriptBox["x", "2"]}], "-", 
       RowBox[{"2", "x"}], "+", "5"}], ")"}]}]}], TraditionalForm]]],
 "; ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"g", "(", "x", ")"}], "=", "x"}], TraditionalForm]]]
}], "Item2Exercise"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    FractionBox[
     SuperscriptBox["x", "4"], 
     RowBox[{
      SuperscriptBox["x", "2"], "-", 
      RowBox[{"4", "x"}], "-", "4"}]]}], TraditionalForm]]],
 "; ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"g", "(", "x", ")"}], "=", 
    SuperscriptBox["x", "2"]}], TraditionalForm]]]
}], "Item2Exercise"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    RowBox[{
     RowBox[{"\[LeftFloor]", "x", "\[RightFloor]"}], "\[CenterDot]", 
     RowBox[{"\[LeftCeiling]", "x", "\[RightCeiling]"}]}]}], 
   TraditionalForm]]],
 "; ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"g", "(", "x", ")"}], "=", 
    SuperscriptBox["x", "2"]}], TraditionalForm]]]
}], "Item2Exercise"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    RowBox[{"n", "\[CenterDot]", 
     RowBox[{"ln", "(", "n", ")"}]}]}], TraditionalForm]]],
 "; ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"g", "(", "x", ")"}], "=", 
    RowBox[{"ln", "(", 
     RowBox[{"n", "!"}], ")"}]}], TraditionalForm]]]
}], "Item2Exercise"]
}, Open  ]],

Cell[TextData[{
 "Using the approach described in Section 3.3 of this manual, compare the \
average-case performance of the ",
 StyleBox["bubbleSort", "Input"],
 " function presented in Section 3.1 to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox[ButtonBox["Sort",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sort"], "FunctionLink"],
 " function."
}], "Item1Exercise"],

Cell[TextData[{
 "Using the solution to Computer Project 9 as a model, compare the \
average-case complexity (as measured by number of comparisons) of the ",
 StyleBox["bubbleSort", "Input"],
 " function with the modified procedure that you implemented as Exercise 7. "
}], "Item1Exercise"],

Cell[TextData[{
 "Using the solution to Computer Project 9 as a model, compare the \
average-case complexity (as measured by number of comparisons) of the ",
 StyleBox["bubbleSort", "Input"],
 " function with the other sort procedures you wrote (e.g., insertion sort, \
selection sort, or binary selection sort)."
}], "Item1Exercise"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{725, 850},
WindowMargins->{{17, Automatic}, {Automatic, 4}},
DockedCells->Cell[
  BoxData[
   TagBox[
    GridBox[{{"\"Exploring Discrete Mathematics with Mathematica\"", 
       ActionMenuBox[
       "\"Navigation\"", {
        "\"CloseAll\"" :> Module[{$CellContext`DJSection$}, SelectionMove[
             SelectedNotebook[], All, Notebook]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; 
           Do[NotebookLocate[$CellContext`DJSection$]; FrontEndExecute[
               FrontEndToken["OpenCloseGroup"]], {$CellContext`DJSection$, {
              "Section1a", "Section1b", "Section1c", "Section2a", "Section2b",
                "Section2c", "Section3a", "Section3b", "SolutionsCE1", 
               "SolutionsCP9", "Section1", "Section2", "Section3", 
               "Solutions", "Exercises"}}]; SelectionMove[
             SelectedNotebook[], Before, Notebook]], "\"Section1\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Solutions", "Exercises"}}]
              NotebookLocate["Section1"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section2\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Solutions", "Exercises"}}]
              NotebookLocate["Section2"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section3\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Solutions", "Exercises"}}]
              NotebookLocate["Section3"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Solutions\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Solutions", "Exercises"}}]
              NotebookLocate["Solutions"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Exercises\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Solutions", "Exercises"}}]
              NotebookLocate["Exercises"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Open All\"" :> 
         Module[{$CellContext`DJSection$}, 
           Do[NotebookLocate[$CellContext`DJSection$]; FrontEndExecute[
               FrontEndToken[
               "SelectionOpenAllGroups"]], {$CellContext`DJSection$, {
              "Exercises", "Section1", "Section1a", "Section1b", "Section1c", 
               "Section2", "Section2a", "Section2b", "Section2c", "Section3", 
               "Section3a", "Section3b", "Solutions", "SolutionsCE1", 
               "SolutionsCP9"}}] SelectionMove[
             SelectedNotebook[], Before, Notebook]]}]}}, 
     GridBoxAlignment -> {
      "Columns" -> {Left, Baseline}, "Rows" -> {Right, Baseline}}, AutoDelete -> 
     False, GridBoxItemSize -> {"Columns" -> {
         Scaled[0.8], 
         Scaled[0.2]}}], "Grid"]], "DockedCell", FontFamily -> "Times"],
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowSelection->True,
Magnification->1,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Book"}, "Textbook.nb", CharacterEncoding -> 
       "UTF-8"]]], 
   Cell[
    StyleData[All, "Printout"], PageWidth -> PaperWidth, 
    CellHorizontalScrolling -> True, 
    CellLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
    ShowAutoStyles -> False, 
    AutoStyleOptions -> {"HighlightMisspelledWords" -> False}, ScriptMinSize -> 
    9, MenuSortingValue -> 1500, 
    PrivateFontOptions -> {"FontType" -> "Outline"}, Magnification -> 1], 
   Cell[
    StyleData["Title"], Editable -> False, ShowCellBracket -> Automatic, 
    CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> False, 
    DefaultNewInlineCellStyle -> {}, LanguageCategory -> "NaturalLanguage", 
    FontFamily -> "Helvetica", FontSize -> 25, FontWeight -> "Bold", 
    FontColor -> GrayLevel[0.137255]], 
   Cell[
    StyleData["BookChapterTitle", StyleDefinitions -> StyleData["Title"]], 
    CellFrame -> {{0, 0}, {1, 1}}, CellDingbat -> Cell[
      BoxData[
       GraphicsBox[{{
          RGBColor[0.09375, 0.570313, 0.816406], 
          RectangleBox[{0, 0}]}, {
          GrayLevel[1], FontSize -> 35, FontWeight -> Bold, FontFamily -> 
          "Helvetica", 
          InsetBox[
           CounterBox["ChapterNumber"], {0.5, 0.45}, {Center, Center}]}}, 
        ImageSize -> {70, 70}]], "Output"], CellMargins -> {{75, 0}, {20, 5}},
     CellFrameColor -> GrayLevel[1]], 
   Cell[
    StyleData["DockedCell"], CellMargins -> {{0, 12}, {0, 0}}, 
    CellGroupingRules -> "TitleGrouping", 
    ConversionRules :> {"TeX" -> {"\n\\chapter{", "}"}}, 
    TaggingRules :> {"CounterSettings" -> {"CounterTarget" -> "CellGroup"}}, 
    PageBreakAbove -> False, PageBreakBelow -> False, LineSpacing -> {1, 2}, 
    MenuSortingValue -> 1105, FontFamily -> "Helvetica", FontSize -> 20, 
    FontWeight -> "Bold", Background -> 
    RGBColor[0.09375, 0.570313, 0.816406]], 
   Cell[
    StyleData["FunctionLink"], ConversionRules :> {"TeX" -> {{"", 
         $CellContext`ExportAsHyperRef[], ""}, {"", Automatic, ""}}}, 
    MenuSortingValue -> 1105, ButtonStyleMenuListing -> None, FontFamily -> 
    "Courier", FontVariations -> {"Underline" -> True}, FontColor -> 
    RGBColor[0, 0, 1], 
    ButtonBoxOptions -> {Active -> True, ButtonFunction :> (FrontEndExecute[{
         FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> ButtonData}], 
   Cell[
    StyleData["Problem"], CellMargins -> {{40, 12}, {15, 15}}, 
    CellGroupingRules -> {"GroupTogetherNestedGrouping", 15010}, 
    ConversionRules :> {
     "TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, ""}}}, 
    TaggingRules :> {
     "ExtraConversionRules" -> {"General" -> {"RestartList" -> False}}}], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Item1Exercise"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item1Exercise"], "."}], CellSize -> {30, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{50, 12}, {3, 5}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17000}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, CounterIncrements -> "Item1Exercise", 
       CounterAssignments -> {{"Item2Exercise", 0}}, MenuSortingValue -> 
       4100], 
      Cell[
       StyleData["Item1Exercise", "Printout"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item1Exercise"], "."}], CellSize -> {20, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{35, 12}, {3, 5}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17000}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["ExerciseContinuation"], CellMargins -> {{50, 12}, {1, 3}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17000}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, MenuSortingValue -> 4101], 
      Cell[
       StyleData["ExerciseContinuation", "Printout"], 
       CellMargins -> {{35, 12}, {1, 3}}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Item2Exercise"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item2Exercise"], "."}], CellSize -> {32, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{75, 12}, {1, 2}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17100}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, CounterIncrements -> "Item2Exercise", MenuSortingValue -> 4200, 
       CounterBoxOptions -> {CounterFunction :> (Part[
           CharacterRange["a", "z"], #]& )}], 
      Cell[
       StyleData["Item2Exercise", "Printout"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item2Exercise"], "."}], CellSize -> {20, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{50, 12}, {1, 2}}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, CounterBoxOptions -> {CounterFunction :> (Part[
           CharacterRange["a", "z"], #]& )}]}, Open]], 
   Cell[
    StyleData["ExerciseEquation"], CellMargins -> {{36, 12}, {7, 7}}, 
    CellGroupingRules -> {"GroupTogetherNestedGrouping", 17200}, 
    CellHorizontalScrolling -> True, 
    CellFrameLabels -> {{None, None}, {None, None}}, DefaultFormatType -> 
    TraditionalForm, InputAutoReplacements -> {}, TextAlignment -> Center, 
    MenuSortingValue -> 4300, 
    ButtonBoxOptions -> {Appearance -> {Automatic, None}}], 
   Cell[
    StyleData["myCode"], CellMargins -> {{66, 10}, {5, 10}}, 
    StyleKeyMapping -> {"=" -> "WolframAlphaShort"}, Evaluatable -> False, 
    CellGroupingRules -> "InputGrouping", TextClipboardType -> "InputText", 
    PageBreakWithin -> False, GroupPageBreakWithin -> False, 
    DefaultFormatType -> DefaultInputFormatType, ContextMenu -> 
    FEPrivate`FrontEndResource["ContextMenus", "myCode"], ShowAutoStyles -> 
    True, "TwoByteSyntaxCharacterAutoReplacement" -> True, 
    HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"}, 
    AutoItalicWords -> {}, LanguageCategory -> "Mathematica", FormatType -> 
    InputForm, NumberMarks -> True, 
    LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, CounterIncrements -> "Code", 
    MenuSortingValue -> 1495, MenuCommandKey -> "8", FontWeight -> 
    "Bold", $CellContext`StripStyleOnPaste -> 
    True, $CellContext`AutoQuoteCharacters -> {}, \
$CellContext`PasteAutoQuoteCharacters -> {}], 
   Cell[
    StyleData["CodeVar"], DefaultFormatType -> DefaultInputFormatType, 
    LineBreakWithin -> False, MenuSortingValue -> 10000, FontWeight -> "Bold",
     FontSlant -> "Italic", FontColor -> GrayLevel[0.4]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Section"], CellFrame -> {{6, 0}, {0, 1}}, ShowCellBracket -> 
       Automatic, CellMargins -> {{12, 12}, {3, 24}}, 
       CellGroupingRules -> {"SectionGrouping", 30}, 
       ConversionRules :> {
        "TeX" -> {"\n\\section{", "}"}, 
         "HTML" -> {"<h3 class=\"Section\">", "</h3>"}}, 
       TaggingRules :> {
        "CounterSettings" -> {
          "CounterFormat" -> {"BookChapterNumber", ".", "Section"}, 
           "CounterTarget" -> "Cell", "XRefPrefix" -> "Section"}}, 
       PageBreakBelow -> False, CellFrameMargins -> {{8, 8}, {4, 6}}, 
       CellFrameColor -> RGBColor[0.09375, 0.570313, 0.816406], TabSpacings -> 
       2.1, CounterIncrements -> {
        "Section", "SectionHeader", "SubsectionHeader", "SubsubsectionHeader",
          "SubsubsubsectionHeader"}, FontFamily -> "Helvetica", FontSize -> 
       16, FontWeight -> "Bold", Background -> GrayLevel[0.999985]], 
      Cell[
       StyleData["Section", "Printout"], CellFrame -> {{4, 0}, {0, 0.5}}, 
       CellMargins -> {{2, 2}, {3, 21}}, PageBreakBelow -> False, 
       CellFrameMargins -> {{6, 6}, {3, 5}}, CellFrameColor -> 
       RGBColor[0.09375, 0.570313, 0.816406]], 
      Cell[
       StyleData["Section", "DoubleSpacedPrintout"], 
       CellFrame -> {{4, 0}, {0, 0.5}}, CellMargins -> {{2, 2}, {3, 21}}, 
       PageBreakBelow -> False, CellFrameMargins -> {{6, 6}, {3, 5}}, 
       CellFrameColor -> RGBColor[0.09375, 0.570313, 0.816406], FontSize -> 
       14]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Subsubsection"], CellDingbat -> None, 
       CellMargins -> {{12, 12}, {0, 6}}, 
       CellElementSpacings -> {"ClosedGroupTopMargin" -> 12}, 
       CellGroupingRules -> {"SectionGrouping", 50}, 
       ConversionRules :> {
        "TeX" -> {"\n\\subsubsection{", "}"}, 
         "HTML" -> {"<h5 class=\"Subsubsection\">", "</h5>"}}, PageBreakBelow -> 
       False, CellFrameLabelMargins -> 4, 
       CounterIncrements -> {
        "Subsubsection", "SubsubsectionHeader", "SubsubsubsectionHeader"}, 
       FontFamily -> "Helvetica", FontSize -> 11, FontWeight -> "Bold", 
       FontSlant -> "Italic"], 
      Cell[
       StyleData["Subsubsection", "Printout"], PageBreakBelow -> False, 
       FontFamily -> "Helvetica", FontSize -> 11, FontWeight -> "Bold", 
       FontSlant -> "Italic"]}, Open]], 
   Cell[
    StyleData["Equation"], CellMargins -> {{26, 10}, {7, 7}}, 
    ConversionRules :> {
     "HTML" -> {{"", ""}, {"<p class=\"Equation\">", "</p>"}}}, 
    CellHorizontalScrolling -> True, DefaultFormatType -> TraditionalForm, 
    InputAutoReplacements -> {}, TextAlignment -> Center, CounterIncrements -> 
    "Equation", ButtonBoxOptions -> {Appearance -> {Automatic, None}}], 
   Cell[
    StyleData["Subsubsubsection"], CellDingbat -> None, 
    CellMargins -> {{12, 12}, {0, 6}}, 
    CellGroupingRules -> {"SectionGrouping", 60}, 
    ConversionRules :> {
     "TeX" -> {"\n\\subsubsubsection{", "}"}, 
      "HTML" -> {"<h6 class=\"Subsubsubsection\">", "</h6>"}}, PageBreakBelow -> 
    False, CellFrameLabelMargins -> 4, 
    CounterIncrements -> {"Subsubsubsection", "SubsubsubsectionHeader"}, 
    FontFamily -> "Helvetica", FontSize -> 11, FontSlant -> "Italic"]}, 
  Visible -> False, FrontEndVersion -> 
  "9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, 2013)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Section1"->{
  Cell[2961, 82, 56, 1, 55, "Section",
   CellTags->"Section1"]},
 "Section1a"->{
  Cell[4317, 115, 58, 1, 32, "Subsection",
   CellTags->"Section1a"]},
 "Section1b"->{
  Cell[12939, 351, 59, 1, 26, "Subsection",
   CellTags->"Section1b"]},
 "Section1c"->{
  Cell[19381, 537, 57, 1, 26, "Subsection",
   CellTags->"Section1c"]},
 "Section2"->{
  Cell[28099, 808, 69, 1, 35, "Section",
   CellTags->"Section2"]},
 "Section2a"->{
  Cell[30350, 888, 107, 5, 33, "Subsection",
   CellTags->"Section2a"]},
 "Section2b"->{
  Cell[181587, 3816, 190, 8, 27, "Subsection",
   CellTags->"Section2b"]},
 "Section2c"->{
  Cell[249302, 5179, 62, 1, 26, "Subsection",
   CellTags->"Section2c"]},
 "Section3"->{
  Cell[258123, 5461, 70, 1, 35, "Section",
   CellTags->"Section3"]},
 "Section3a"->{
  Cell[261486, 5556, 59, 1, 32, "Subsection",
   CellTags->"Section3a"]},
 "Section3b"->{
  Cell[282265, 5956, 107, 2, 26, "Subsection",
   CellTags->"Section3b"]},
 "Solutions"->{
  Cell[292676, 6266, 115, 3, 35, "Section",
   CellTags->"Solutions"]},
 "SolutionsCP9"->{
  Cell[292816, 6273, 67, 1, 32, "Subsection",
   CellTags->"SolutionsCP9"]},
 "SolutionsCE1"->{
  Cell[321002, 7061, 105, 2, 26, "Subsection",
   PageBreakWithin->False,
   CellTags->"SolutionsCE1"]},
 "Exercises"->{
  Cell[326254, 7244, 52, 1, 35, "Section",
   CellTags->"Exercises"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Section1", 346736, 7735},
 {"Section1a", 346818, 7738},
 {"Section1b", 346905, 7741},
 {"Section1c", 346993, 7744},
 {"Section2", 347080, 7747},
 {"Section2a", 347164, 7750},
 {"Section2b", 347253, 7753},
 {"Section2c", 347344, 7756},
 {"Section3", 347433, 7759},
 {"Section3a", 347519, 7762},
 {"Section3b", 347609, 7765},
 {"Solutions", 347700, 7768},
 {"SolutionsCP9", 347791, 7771},
 {"SolutionsCE1", 347887, 7774},
 {"Exercises", 348008, 7778}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 83, 1, 96, "BookChapterTitle",
 CounterAssignments->{{"ChapterNumber", 3}}],
Cell[CellGroupData[{
Cell[687, 27, 31, 0, 55, "Section"],
Cell[721, 29, 712, 15, 65, "Text"],
Cell[1436, 46, 1488, 31, 140, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2961, 82, 56, 1, 55, "Section",
 CellTags->"Section1"],
Cell[3020, 85, 779, 14, 95, "Text"],
Cell[3802, 101, 490, 10, 50, "Text"],
Cell[CellGroupData[{
Cell[4317, 115, 58, 1, 32, "Subsection",
 CellTags->"Section1a"],
Cell[4378, 118, 664, 10, 80, "Text"],
Cell[5045, 130, 404, 8, 36, "Text"],
Cell[5452, 140, 321, 9, 60, "myCode"],
Cell[5776, 151, 523, 14, 52, "Text"],
Cell[6302, 167, 352, 6, 50, "Text"],
Cell[6657, 175, 415, 12, 76, "myCode"],
Cell[7075, 189, 334, 8, 36, "Text"],
Cell[7412, 199, 703, 20, 92, "myCode"],
Cell[8118, 221, 228, 6, 21, "Text"],
Cell[8349, 229, 916, 18, 82, "Text"],
Cell[9268, 249, 981, 27, 108, "myCode"],
Cell[10252, 278, 159, 3, 20, "Text"],
Cell[10414, 283, 1045, 29, 125, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[11484, 316, 172, 5, 28, "Input"],
Cell[11659, 323, 29, 0, 28, "Output"]
}, Open  ]],
Cell[11703, 326, 591, 9, 80, "Text"],
Cell[12297, 337, 605, 9, 80, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[12939, 351, 59, 1, 26, "Subsection",
 CellTags->"Section1b"],
Cell[13001, 354, 418, 7, 50, "Text"],
Cell[13422, 363, 810, 23, 65, "Text"],
Cell[14235, 388, 1595, 41, 261, "Input"],
Cell[15833, 431, 88, 2, 20, "Text"],
Cell[CellGroupData[{
Cell[15946, 437, 304, 7, 29, "Input"],
Cell[16253, 446, 28, 0, 28, "Output"]
}, Open  ]],
Cell[16296, 449, 243, 6, 35, "Text"],
Cell[16542, 457, 1728, 44, 277, "Input",
 InitializationCell->True],
Cell[18273, 503, 44, 0, 20, "Text"],
Cell[CellGroupData[{
Cell[18342, 507, 304, 7, 29, "Input"],
Cell[18649, 516, 29, 0, 28, "Output"]
}, Open  ]],
Cell[18693, 519, 651, 13, 81, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[19381, 537, 57, 1, 26, "Subsection",
 CellTags->"Section1c"],
Cell[19441, 540, 133, 3, 20, "Text"],
Cell[19577, 545, 251, 4, 35, "Text"],
Cell[19831, 551, 1422, 38, 154, "myCode"],
Cell[21256, 591, 531, 14, 52, "Text"],
Cell[21790, 607, 1502, 41, 154, "myCode"],
Cell[23295, 650, 758, 21, 70, "Text"],
Cell[24056, 673, 467, 13, 53, "Text"],
Cell[24526, 688, 225, 5, 36, "Text"],
Cell[CellGroupData[{
Cell[24776, 697, 97, 2, 16, "Item1Numbered"],
Cell[24876, 701, 95, 2, 16, "Item1Numbered"],
Cell[24974, 705, 124, 3, 16, "Item1Numbered"]
}, Open  ]],
Cell[25113, 711, 838, 26, 108, "Input",
 InitializationCell->True],
Cell[25954, 739, 332, 7, 36, "Text"],
Cell[26289, 748, 1409, 38, 169, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[27723, 790, 175, 5, 28, "Input"],
Cell[27901, 797, 137, 4, 28, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[28099, 808, 69, 1, 35, "Section",
 CellTags->"Section2"],
Cell[28171, 811, 1091, 33, 65, "Text"],
Cell[29265, 846, 1060, 38, 43, "Text"],
Cell[CellGroupData[{
Cell[30350, 888, 107, 5, 33, "Subsection",
 CellTags->"Section2a"],
Cell[30460, 895, 298, 7, 21, "Text"],
Cell[CellGroupData[{
Cell[30783, 906, 242, 8, 28, "Input",
 InitializationCell->True],
Cell[31028, 916, 189, 6, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31254, 927, 100, 3, 29, "Input",
 InitializationCell->True],
Cell[31357, 932, 51, 1, 30, "Output"]
}, Open  ]],
Cell[31423, 936, 528, 15, 51, "Text"],
Cell[31954, 953, 260, 9, 20, "Text"],
Cell[CellGroupData[{
Cell[32239, 966, 141, 4, 28, "Input"],
Cell[32383, 972, 4083, 74, 237, "Output"]
}, Open  ]],
Cell[36481, 1049, 1270, 41, 87, "Text"],
Cell[CellGroupData[{
Cell[37776, 1094, 476, 14, 29, "Input"],
Cell[38255, 1110, 44702, 750, 127, "Output"]
}, Open  ]],
Cell[82972, 1863, 977, 31, 52, "Text"],
Cell[CellGroupData[{
Cell[83974, 1898, 192, 5, 29, "Input"],
Cell[84169, 1905, 8626, 150, 224, 3614, 66, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[92810, 2058, 583, 20, 35, "Text"],
Cell[CellGroupData[{
Cell[93418, 2082, 268, 8, 29, "Input"],
Cell[93689, 2092, 9874, 170, 234, 3614, 66, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[103578, 2265, 899, 25, 52, "Text"],
Cell[CellGroupData[{
Cell[104502, 2294, 353, 11, 29, "Input"],
Cell[104858, 2307, 6234, 109, 239, 2032, 39, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[111107, 2419, 346, 9, 37, "Text"],
Cell[111456, 2430, 247, 6, 21, "Text"],
Cell[CellGroupData[{
Cell[111728, 2440, 190, 6, 29, "Input"],
Cell[111921, 2448, 8683, 151, 240, "Output"]
}, Open  ]],
Cell[120619, 2602, 1355, 49, 83, "Text"],
Cell[CellGroupData[{
Cell[121999, 2655, 299, 9, 29, "Input"],
Cell[122301, 2666, 17607, 299, 240, 8671, 151, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[139923, 2968, 387, 10, 36, "Text"],
Cell[140313, 2980, 469, 13, 21, "Text"],
Cell[140785, 2995, 435, 11, 36, "Text"],
Cell[CellGroupData[{
Cell[141245, 3010, 248, 7, 29, "Input"],
Cell[141496, 3019, 12822, 244, 242, "Output"]
}, Open  ]],
Cell[154333, 3266, 305, 7, 21, "Text"],
Cell[CellGroupData[{
Cell[154663, 3277, 261, 8, 29, "Input"],
Cell[154927, 3287, 13003, 250, 242, "Output"]
}, Open  ]],
Cell[167945, 3540, 161, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[168131, 3547, 307, 9, 29, "Input"],
Cell[168441, 3558, 12545, 236, 242, "Output"]
}, Open  ]],
Cell[181001, 3797, 549, 14, 37, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[181587, 3816, 190, 8, 27, "Subsection",
 CellTags->"Section2b"],
Cell[181780, 3826, 512, 15, 36, "Text"],
Cell[CellGroupData[{
Cell[182317, 3845, 343, 11, 29, "Input"],
Cell[182663, 3858, 12548, 236, 242, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[195248, 4099, 343, 11, 29, "Input"],
Cell[195594, 4112, 12548, 236, 242, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[208179, 4353, 343, 11, 29, "Input"],
Cell[208525, 4366, 12548, 236, 242, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[221110, 4607, 343, 11, 29, "Input"],
Cell[221456, 4620, 12552, 236, 242, "Output"]
}, Open  ]],
Cell[234023, 4859, 585, 23, 41, "Text"],
Cell[CellGroupData[{
Cell[234633, 4886, 344, 11, 29, "Input"],
Cell[234980, 4899, 13773, 256, 235, "Output"]
}, Open  ]],
Cell[248768, 5158, 497, 16, 41, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[249302, 5179, 62, 1, 26, "Subsection",
 CellTags->"Section2c"],
Cell[249367, 5182, 1312, 47, 58, "Text"],
Cell[CellGroupData[{
Cell[250704, 5233, 320, 11, 29, "Input",
 InitializationCell->True],
Cell[251027, 5246, 265, 9, 33, "Output"]
}, Open  ]],
Cell[251307, 5258, 1115, 30, 69, "Text"],
Cell[252425, 5290, 1089, 27, 101, "Text"],
Cell[CellGroupData[{
Cell[253539, 5321, 768, 23, 53, "Input",
 InitializationCell->True],
Cell[254310, 5346, 1842, 37, 358, "Output"]
}, Open  ]],
Cell[256167, 5386, 331, 10, 36, "Text"],
Cell[256501, 5398, 720, 24, 38, "Text"],
Cell[257224, 5424, 850, 31, 36, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[258123, 5461, 70, 1, 35, "Section",
 CellTags->"Section3"],
Cell[258196, 5464, 328, 5, 50, "Text"],
Cell[258527, 5471, 493, 8, 65, "Text"],
Cell[259023, 5481, 727, 15, 81, "Text"],
Cell[259753, 5498, 462, 11, 51, "Text"],
Cell[260218, 5511, 187, 6, 21, "Text"],
Cell[CellGroupData[{
Cell[260430, 5521, 130, 3, 29, "Input"],
Cell[260563, 5526, 139, 4, 28, "Output"]
}, Open  ]],
Cell[260717, 5533, 744, 19, 52, "Text"],
Cell[CellGroupData[{
Cell[261486, 5556, 59, 1, 32, "Subsection",
 CellTags->"Section3a"],
Cell[261548, 5559, 604, 9, 80, "Text"],
Cell[262155, 5570, 789, 19, 67, "Text"],
Cell[CellGroupData[{
Cell[262969, 5593, 97, 2, 29, "Input"],
Cell[263069, 5597, 103, 2, 28, "Output"]
}, Open  ]],
Cell[263187, 5602, 420, 11, 37, "Text"],
Cell[CellGroupData[{
Cell[263632, 5617, 225, 6, 29, "Input"],
Cell[263860, 5625, 88, 1, 28, "Output"]
}, Open  ]],
Cell[263963, 5629, 2051, 57, 101, "Text"],
Cell[CellGroupData[{
Cell[266039, 5690, 619, 15, 122, "Input",
 InitializationCell->True],
Cell[266661, 5707, 7579, 106, 224, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[274277, 5818, 179, 5, 29, "Input",
 InitializationCell->True],
Cell[274459, 5825, 7199, 103, 209, "Output"]
}, Open  ]],
Cell[281673, 5931, 153, 3, 20, "Text"],
Cell[281829, 5936, 203, 6, 21, "Text"],
Cell[CellGroupData[{
Cell[282057, 5946, 68, 1, 29, "Input"],
Cell[282128, 5949, 88, 1, 28, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[282265, 5956, 107, 2, 26, "Subsection",
 CellTags->"Section3b"],
Cell[282375, 5960, 564, 16, 36, "Text"],
Cell[CellGroupData[{
Cell[282964, 5980, 393, 13, 28, "Input"],
Cell[283360, 5995, 416, 11, 242, "Output"]
}, Open  ]],
Cell[283791, 6009, 413, 9, 37, "Text"],
Cell[284207, 6020, 2058, 55, 236, "Input",
 InitializationCell->True],
Cell[286268, 6077, 3075, 86, 165, "Text"],
Cell[289346, 6165, 89, 2, 20, "Text"],
Cell[CellGroupData[{
Cell[289460, 6171, 176, 4, 29, "Input",
 InitializationCell->True],
Cell[289639, 6177, 706, 25, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[290382, 6207, 98, 2, 28, "Input",
 InitializationCell->True],
Cell[290483, 6211, 537, 13, 235, "Output"]
}, Open  ]],
Cell[291035, 6227, 345, 7, 51, "Text"],
Cell[291383, 6236, 211, 4, 35, "Text"],
Cell[291597, 6242, 783, 12, 95, "Text"],
Cell[292383, 6256, 244, 4, 35, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[292676, 6266, 115, 3, 35, "Section",
 CellTags->"Solutions"],
Cell[CellGroupData[{
Cell[292816, 6273, 67, 1, 32, "Subsection",
 CellTags->"SolutionsCP9"],
Cell[292886, 6276, 392, 12, 55, "Problem"],
Cell[293281, 6290, 346, 13, 20, "Text"],
Cell[293630, 6305, 907, 25, 80, "Text"],
Cell[294540, 6332, 354, 9, 36, "Text"],
Cell[294897, 6343, 1702, 43, 277, "myCode"],
Cell[296602, 6388, 1159, 30, 84, "Text"],
Cell[297764, 6420, 334, 8, 36, "Text"],
Cell[298101, 6430, 2013, 50, 308, "Input",
 InitializationCell->True],
Cell[300117, 6482, 74, 0, 20, "Text"],
Cell[CellGroupData[{
Cell[300216, 6486, 124, 3, 29, "Input"],
Cell[300343, 6491, 29, 0, 28, "Output"]
}, Open  ]],
Cell[300387, 6494, 28, 0, 20, "Text"],
Cell[300418, 6496, 761, 25, 50, "Text"],
Cell[301182, 6523, 369, 12, 59, "Equation"],
Cell[301554, 6537, 317, 9, 21, "Text"],
Cell[CellGroupData[{
Cell[301896, 6550, 215, 7, 28, "Input"],
Cell[302114, 6559, 120, 4, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[302271, 6568, 61, 1, 29, "Input"],
Cell[302335, 6571, 50, 1, 28, "Output"]
}, Open  ]],
Cell[302400, 6575, 246, 9, 21, "Text"],
Cell[302649, 6586, 329, 8, 35, "Text"],
Cell[302981, 6596, 1104, 30, 153, "Input",
 InitializationCell->True],
Cell[304088, 6628, 420, 11, 36, "Text"],
Cell[304511, 6641, 301, 8, 35, "Text"],
Cell[CellGroupData[{
Cell[304837, 6653, 63, 1, 29, "Input"],
Cell[304903, 6656, 32, 0, 28, "Output"]
}, Open  ]],
Cell[304950, 6659, 272, 11, 20, "Text"],
Cell[305225, 6672, 817, 21, 68, "Text"],
Cell[CellGroupData[{
Cell[306067, 6697, 286, 8, 29, "Input",
 InitializationCell->True],
Cell[306356, 6707, 1591, 33, 237, "Output"]
}, Open  ]],
Cell[307962, 6743, 16, 0, 20, "Text"],
Cell[307981, 6745, 726, 23, 37, "Text"],
Cell[308710, 6770, 326, 10, 29, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[309061, 6784, 208, 5, 29, "Input",
 InitializationCell->True],
Cell[309272, 6791, 1373, 28, 242, "Output"]
}, Open  ]],
Cell[310660, 6822, 169, 6, 21, "Text"],
Cell[CellGroupData[{
Cell[310854, 6832, 139, 3, 29, "Input",
 InitializationCell->True],
Cell[310996, 6837, 2679, 52, 237, "Output"]
}, Open  ]],
Cell[313690, 6892, 360, 10, 21, "Text"],
Cell[CellGroupData[{
Cell[314075, 6906, 436, 12, 45, "Input"],
Cell[314514, 6920, 6439, 135, 239, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[321002, 7061, 105, 2, 26, "Subsection",
 PageBreakWithin->False,
 CellTags->"SolutionsCE1"],
Cell[321110, 7065, 1481, 64, 61, "Problem",
 PageBreakAbove->False,
 PageBreakWithin->False],
Cell[322594, 7131, 1462, 50, 69, "Text"],
Cell[CellGroupData[{
Cell[324081, 7185, 533, 17, 45, "Input",
 InitializationCell->True],
Cell[324617, 7204, 1576, 33, 312, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[326254, 7244, 52, 1, 35, "Section",
 CellTags->"Exercises"],
Cell[CellGroupData[{
Cell[326331, 7249, 292, 8, 33, "Item1Exercise"],
Cell[326626, 7259, 116, 3, 20, "Item1Exercise"],
Cell[326745, 7264, 117, 3, 20, "Item1Exercise"],
Cell[326865, 7269, 133, 3, 20, "Item1Exercise"],
Cell[327001, 7274, 133, 3, 20, "Item1Exercise"],
Cell[327137, 7279, 166, 3, 20, "Item1Exercise"],
Cell[327306, 7284, 200, 5, 34, "Item1Exercise"],
Cell[327509, 7291, 229, 6, 33, "Item1Exercise"],
Cell[327741, 7299, 236, 6, 33, "Item1Exercise"],
Cell[327980, 7307, 252, 6, 33, "Item1Exercise"],
Cell[328235, 7315, 579, 20, 33, "Item1Exercise"],
Cell[CellGroupData[{
Cell[328839, 7339, 431, 16, 21, "Item2Exercise"],
Cell[329273, 7357, 412, 16, 31, "Item2Exercise"],
Cell[329688, 7375, 418, 15, 18, "Item2Exercise"],
Cell[330109, 7392, 370, 14, 15, "Item2Exercise"]
}, Open  ]],
Cell[330494, 7409, 395, 12, 35, "Item1Exercise"],
Cell[330892, 7423, 290, 5, 34, "Item1Exercise"],
Cell[331185, 7430, 334, 6, 47, "Item1Exercise"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
